@@ -9,7 +9,7 @@
 ### This code was originally written to package up BitPim but has been
 ### refactored to build almost any Python program.
 ###
-### $Id: makedist.py 3147 2006-04-24 14:10:55Z skyjunky $
+### $Id: makedist.py 4278 2007-06-12 02:30:38Z djpham $
 
 
 # Runs on Linux, Windows and Mac
@@ -26,6 +26,10 @@ import glob
 import re
 import StringIO, traceback
 import distutils.core
+import email.Utils
+import time
+import zipfile
+import getopt
 
 # i got real tired of typing these and having the lines get really long
 opj=os.path.join
@@ -33,7 +37,7 @@ opd=os.path.dirname
 opb=os.path.basename
 
 # Aribtrary constants
-PATH_CXFREEZE="/opt/cx_Freeze-3.0.2"
+PATH_CXFREEZE="/opt/cx_Freeze-3.0.3"
 PATH_INNOSETUP="c:\\program files\\inno setup 5\\compil32.exe"
 RT_MANIFEST = 24
 WINXP_MANIFEST=manifest_template = '''
@@ -222,8 +226,9 @@ def windowsbuild(pkg, vals):
     # Run innosetup
     run("c:\\program files\\inno setup 5\\compil32.exe", "/cc", opj("dist", opb(vals['ISSFILE'])))
 
-def linuxrpmbuild(pkg, vals):
-    """Do all the steps necessary to make a Linux RPM"""
+def linuxcommonbuild(pkg, vals):
+    """Do all the steps necessary to make a Linux filesystem build,
+    ready for packaging"""
     clean()
 
     # make it look like cx-Freeze supports py2exe/py2app style options
@@ -312,7 +317,7 @@ def linuxrpmbuild(pkg, vals):
     for so in recursiveglob(opj(opts['options']['cxfreeze']['dist_dir'], "*.so")):
         for line in os.popen("ldd "+so, "r"):
             line=line.split()
-            if line[2].startswith("/usr/lib/wxPython-"):
+            if line[-2].startswith("/usr/lib/wxPython-"):
                 pd=opd(so)
                 libs=copy.get(pd, [])
                 if line[2] not in libs:
@@ -331,14 +336,18 @@ def linuxrpmbuild(pkg, vals):
     # fixups (permissions, files)
     if hasattr(pkg, "finalize"):
         pkg.finalize(distdir)
+    return opts
 
+def linuxrpmbuild(pkg, vals):
+    """Do all the steps necessary to make a Linux RPM"""
+    # Build the tree
+    opts=linuxcommonbuild(pkg, vals)
     # make a rpm.  this will contain a tar file of our code (dist.tar), a spec file,
     # and a makefile
-    
     import tarfile
     distfilesdir=opj(opts['options']['cxfreeze']['dist_dir'])
     distdir=opd(distfilesdir)
-    builddir=os.path.join(distdir, "build")
+    builddir=opj(distdir, "build")
     os.mkdir(builddir)
 
 
@@ -372,7 +381,36 @@ def linuxrpmbuild(pkg, vals):
 
     for rpm in recursiveglob(opj(rpmdir, "RPMS", "*.rpm")):
         shutil.copy2(rpm, distdir)
-    
+
+def linuxdebbuild(pkg, vals):
+    """Do all the steps necessary to make a Linux deb package"""
+    # Build the tree
+    opts=linuxcommonbuild(pkg, vals)
+    # Setting up the dir structure
+    distfilesdir=opj(opts['options']['cxfreeze']['dist_dir'])
+    distdir=opd(distfilesdir)
+    builddir=opj(distdir, "build")
+    os.mkdir(builddir)
+    _debiandir=opj(builddir, 'debian')
+    _debianbitpimdir=opj(_debiandir, 'bitpim')
+    # copy the contents of debian dir over
+    shutil.copytree(opj('packaging', 'debian'), _debiandir)
+    # extract the versionhsitory (as changelog) file
+    file(opj(_debiandir, 'versionhistory.htm'), 'wt').write(
+        zipfile.ZipFile(opj('resources', 'bitpim.htb'), 'r').read('versionhistory.htm'))
+    # copy the dist tree over
+    shutil.copytree(distfilesdir, _debianbitpimdir)
+    # update various variables in the control areas
+    for _file in ('changelog', 'postinst', 'postrm'):
+        _filename=opj(_debiandir, _file)
+        dosubs(vals, _filename, _filename)
+    # Build the deb package
+    print 'Building deb package'
+    _pwd=os.getcwd()
+    os.chdir(builddir)
+    run(opj('debian', 'rules'), "binary")
+    os.chdir(_pwd)
+
 def macbuild(pkg, vals):
     """Do all the steps necessary to make a Mac dimg
     
@@ -409,7 +447,9 @@ def macbuild(pkg, vals):
                          'CFBundleGetInfoString': '%%NAME%%-%%VERSION%%',
                          'CFBundleExecutable': '%%NAME%%',
                          'CFBundleIdentifier': '%%GUID%%',
+                         'PyResourcePackages': ['lib/python2.3/lib-dynload'],
                       },
+                    'prefer_ppc': 'true',
                  },
              },
         'script_args': ('py2app',),
@@ -450,7 +490,7 @@ def sanitycheck():
     if sys.platform=="win32":
         print "py2exe version",
         import py2exe
-        expect='0.6.5'
+        expect='0.6.6'
         if py2exe.__version__!=expect:
             raise Exception("Should be %s version of py2exe - you have %s" % (expect, py2exe.__version__))
         print "  OK"
@@ -462,7 +502,7 @@ def sanitycheck():
     if sys.platform=="darwin":
         print "py2app version",
         import py2app
-        expect='0.2'
+        expect='0.3.6'
         if py2app.__version__!=expect:
             raise Exception("Should be %s version of py2app - you have %s" % (expect, py2app.__version__))
         print "  OK"
@@ -575,12 +615,27 @@ if __name__=='__main__':
         sys.exit(127)
     sys.excepthook=eh
 
-    # find support script (default src/package.py)
-    import sys
-    if len(sys.argv)==2:
-        pkg=sys.argv[1]
-    else:
-        pkg="src/package.py"
+    try:
+        _options, _args=getopt.gnu_getopt(sys.argv[1:], 'p:v:')
+        if _args:
+            raise getopt.GetoptError('Invalid argument')
+        _invalid_opt=False
+    except getopt.GetoptError:
+        _error_str=sys.exc_info()[1].msg
+        _invalid_opt=True
+    if _invalid_opt:
+        print _error_str
+        print 'Usage: %s [-p <package module>] [-v <version>]'%sys.argv[0]
+        sys.exit(1)
+
+    # default support script and version
+    pkg="src/package.py"
+    _thisversion=None
+    for _k, _v in _options:
+        if _k=='-p':
+            pkg=_v
+        elif _k=='-v':
+            _thisversion=_v
 
     print "Using package file",pkg
 
@@ -596,6 +651,10 @@ if __name__=='__main__':
         pkg.ensureofficial()
 
     vals=pkg.getvals()
+    if _thisversion:
+        vals['VERSION']=_thisversion
+    print 'version', vals['VERSION']
+
     # fixup vals
     if 'OUTFILEPREFIX' not in vals:
         vals['OUTFILEPREFIX']=""
@@ -606,13 +665,17 @@ if __name__=='__main__':
     setupconfig()
     if 'PUBLISHER' not in vals:
         vals['PUBLISHER']=makeconfig('PUBLISHER', "Enter your name and email address as the packager/publisher of this build\nFor example Joe Acme <joe.acme@example.com>")
+    vals['BUILDDATETIME']=email.Utils.formatdate(time.time(), True)
     
     if sys.platform=='win32':
         windowsbuild(pkg, vals)
     elif sys.platform.startswith('linux'):
         import platform
-        if platform.dist()[0].lower() in ('redhat', 'suse', 'mandrake'):
+        _platformname=platform.dist()[0].lower()
+        if _platformname in ('redhat', 'suse', 'mandrake'):
             linuxrpmbuild(pkg, vals)
+        elif _platformname=='debian':
+            linuxdebbuild(pkg, vals)
         else:
             raise Exception("Don't know what to do with "+`platform.dist()`)
     elif sys.platform=='darwin':
