@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: bp.py 3775 2006-12-14 22:22:12Z djpham $
+### $Id: bp.py 4287 2007-06-12 02:33:21Z djpham $
 
 """Main entry point to Bitpim
 
@@ -51,11 +51,12 @@ if __name__ == '__main__':
 	# get rid of the process serial number on mac
 	sys.argv=sys.argv[:1]+sys.argv[2:]
     try:
-        _options, _args=getopt.getopt(sys.argv[1:], 'c:d:')
+        _options, _args=getopt.gnu_getopt(sys.argv[1:], 'c:d:')
         _invalid_args=[x for x in _args if x not in ['debug', 'bitfling']]
         if _invalid_args:
             raise getopt.GetoptError('Invalid argument(s): '+','.join(_invalid_args))
-    except getopt.GetoptError,e:
+    except getopt.GetoptError:
+        e=sys.exc_info()[1]
         _invalid_args=True
         _error_str=e.msg
     if _invalid_args:
