@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: bphtml.py 3793 2006-12-22 04:00:51Z djpham $
+### $Id: bphtml.py 4230 2007-05-10 22:52:21Z djpham $
 
 # Standard modules
 import copy
@@ -28,14 +28,6 @@ import common
 ###  Enhanced HTML Widget
 ###
 
-_basefonts=[wx.html.HTML_FONT_SIZE_1, wx.html.HTML_FONT_SIZE_2,
-wx.html.HTML_FONT_SIZE_3, wx.html.HTML_FONT_SIZE_4,
-wx.html.HTML_FONT_SIZE_5, wx.html.HTML_FONT_SIZE_6,
-wx.html.HTML_FONT_SIZE_7 ]
-
-def getbasefontsizes(scale=1.0):
-    return [int(scale*sz) for sz in _basefonts]
-
 class HTMLWindow(wx.html.HtmlWindow):
     """BitPim customised HTML Window
 
@@ -49,10 +41,11 @@ class HTMLWindow(wx.html.HtmlWindow):
         wx.html.HtmlWindow.__init__(self, parent, id)
         wx.EVT_KEY_UP(self, self.OnKeyUp)
         self.thetext=""
+        self._normal_font_size=max(wx.NORMAL_FONT.GetPointSize(), 10)
         self.SetFontScale(relsize)
 
     def SetFontScale(self, scale):
-        self.SetFonts("", "", getbasefontsizes(scale))
+        self.SetStandardFonts(int(scale*self._normal_font_size), '', '')
         # the html widget clears itself if you set the scale
         if len(self.thetext):
             wx.html.HtmlWindow.SetPage(self,self.thetext)
@@ -285,7 +278,8 @@ class PrintData(wx.PrintData):
     """
     # the names of Get/Set attributes to copy from source to dest object
     _attr_names=("Collate", "Colour", "Duplex", "NoCopies",
-                 "Orientation", "PaperId", "PrinterName")
+                 "Orientation", "PaperId", "PrinterName",
+                 "PaperSize")
     def __init__(self, rhs=None):
         super(PrintData, self).__init__()
         if rhs is not None:
@@ -352,14 +346,15 @@ class HtmlEasyPrinting:
             pd=self.printData.copy()
         else:
             pd=PrintData()
-        pd.SetOrientation(wx.PORTRAIT)
+        if not pd.Orientation:
+            pd.SetOrientation(wx.PORTRAIT)
         preview=wx.PrintPreview(printout1, printout2, pd)
         if not preview.Ok():
             print "preview problem"
             assert False, "preview problem"
             return
         self.frame=wx.PreviewFrame(preview, self.parent, "Print Preview")
-        guiwidgets.set_size("PrintPreview", self.frame, screenpct=90, aspect=0.58)
+        self.guiwidgets.set_size("PrintPreview", self.frame, screenpct=90, aspect=0.58)
         wx.EVT_CLOSE(self.frame, self.OnPreviewClose)
         self.frame.Initialize()
         # self.frame.SetPosition(self.parent.GetPosition())
@@ -370,6 +365,7 @@ class HtmlEasyPrinting:
         pdd=wx.PrintDialogData()
         if self.printData.Ok():
             pdd.SetPrintData(self.printData.copy())
+        if not pdd.GetPrintData().Orientation:
             pdd.GetPrintData().SetOrientation(wx.PORTRAIT)
         printer=wx.Printer(pdd)
         printout=self._getprintout(htmltext, basepath, scale)
@@ -377,7 +373,6 @@ class HtmlEasyPrinting:
         printout.Destroy()
 
     def _getprintout(self, htmltext, basepath, scale):
-##        print "scale is",scale," margins are", self.margins
         printout=wx.html.HtmlPrintout()
         basesizes=[7,8,10,12,16,22,30]
         printout.SetFonts("", "", [int(sz*scale) for sz in basesizes])
@@ -445,7 +440,7 @@ class HtmlEasyPrinting:
         self.margins=[tl[1],br[1],tl[0],br[0]]
 
     def OnPreviewClose(self, event):
-        guiwidgets.save_size("PrintPreview", self.frame.GetRect())
+        self.guiwidgets.save_size("PrintPreview", self.frame.GetRect())
         event.Skip()
 
 # scaling factor for the various font sizes
@@ -473,7 +468,7 @@ class Renderer:
         if Renderer._lastsize!=size or Renderer._lastfont!=font:
             Renderer._hdc.SetFonts(font, "", [int(x*size) for x in _scales])
         Renderer._hdc.SetHtmlText(html, basepath)
-        Renderer._hdc.Render(0,0,0,False)
+        Renderer._hdc.Render(0, 0, (), 0, False)
         return (Renderer._mdc.MaxX(), Renderer._mdc.MaxY())
 
     getbestsize=staticmethod(getbestsize)
@@ -492,7 +487,7 @@ def drawhtml(dc, rect, html, basepath="", font="", size=10):
     hdc.SetDC(dc, 1)
     hdc.SetSize(rect.width, rect.height)
     hdc.SetHtmlText(html, basepath)
-    hdc.Render(rect.x, rect.y, 0, False)
+    hdc.Render(rect.x, rect.y, (), 0, False)
     dc.SetUserScale(*origscale)
 
 
