@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: calendarcontrol.py 3662 2006-11-09 22:43:23Z djpham $
+### $Id: calendarcontrol.py 3949 2007-01-30 23:17:40Z djpham $
 
 """A calendar control that shows several weeks in one go
 
@@ -812,7 +812,7 @@ class PopupCalendar(wx.Dialog):
         wx.calendar.EVT_CALENDAR(self, self.control.GetId(), self.OnCalSelected)
 
     def Popup(self, year, month, day, event):
-        d=wx.DateTimeFromDMY(day, month, year)
+        d=wx.DateTimeFromDMY(day, month-1, year)
         self.control.SetDate(d)
         btn=event.GetEventObject()
         pos=btn.ClientToScreen( (0,0) )
