@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: call_history.py 3349 2006-06-07 21:47:58Z djpham $
+### $Id: call_history.py 3841 2007-01-03 03:30:29Z djpham $
 
 """
 Code to handle Call History data storage and display.
@@ -46,6 +46,7 @@ import wx.lib.scrolledpanel as scrolled
 import database
 import guiwidgets
 import guihelper
+import helpids
 import phonenumber
 import pubsub
 import today
@@ -608,4 +609,5 @@ class CallHistoryList(wx.Panel, widgets.BitPimWidget):
             self.populate()
             self._stats._save_to_db(self._stats._data)
             self._stats.CalculateStats()
-
+    def GetHelpID(self):
+        return helpids.ID_TAB_CALLHISTORY
