@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: common.py 3795 2006-12-23 10:43:23Z rogerb $
+### $Id: common.py 4210 2007-05-03 21:42:01Z djpham $
 
 
 # Documentation
@@ -48,10 +48,11 @@ class HelperBinaryNotFound(Exception):
           self.paths=paths
 
 class CommandExecutionFailed(Exception):
-     def __init__(self, retcode, args):
+     def __init__(self, retcode, args, logstr=None):
           Exception.__init__(self, "Command execution failed with code %d: %s" % (retcode, " ".join(args)))
           self.retcode=retcode
           self.args=args
+          self.logstr=logstr
           
 class ConversionNotSupported(Exception):
      def __init__(self, msg):
@@ -311,10 +312,13 @@ def formatexception(excinfo=None, lastframes=8):
                     print >>s,"(Exception occurred printing value)"
      return s.getvalue()
                     
-def gettempfilename(extension):
+def gettempfilename(extension=None):
     "Returns a filename to be used for a temporary file"
     # safest Python 2.3 method
-    x=tempfile.NamedTemporaryFile(suffix="."+extension)
+    if extension:
+        x=tempfile.NamedTemporaryFile(suffix="."+extension)
+    else:
+        x=tempfile.NamedTemporaryFile()
     n=x.name
     x.close()
     del x
@@ -398,8 +402,8 @@ except:  pass
 try:
      import encodings.utf_16
      _boms.append( (codecs.BOM_UTF16, "utf_16") )
-     _boms.append( (codecs.BOM_UTF16_BE, "utf_16") )
-     _boms.append( (codecs.BOM_UTF16_LE, "utf_16") )
+     _boms.append( (codecs.BOM_UTF16_BE, "utf_16_be") )
+     _boms.append( (codecs.BOM_UTF16_LE, "utf_16_le") )
 except:  pass
 
 # 8 bit
@@ -408,6 +412,12 @@ try:
      _boms.append( (codecs.BOM_UTF8, "utf_8") )
 except: pass
 
+# Work arounds for the idiots at Apple that decided not to even
+# include BOMs
+_boms.append( ("\0B\0E\0G\0I\0N\0:\0V\0C\0A\0R\0D", "utf_16_be") )
+_boms.append( ("B\0E\0G\0I\0N\0:\0V\0C\0A\0R\0D\0", "utf_16_le") )
+
+
 # NB: the 32 bit and 64 bit versions have the BOM constants defined in Py 2.3
 # but no corresponding encodings module.  They are here for completeness.
 # The order of above also matters since the first ones have longer
@@ -851,3 +861,17 @@ def get_main_dir():
         return os.path.abspath(os.path.dirname(sys.executable))
     # running from src, up one
     return os.path.split(os.path.abspath(os.path.dirname(sys.argv[0])))[0]
+
+if sys.platform=='win32':
+    # From Tim Golden's Win32 How Do I ...?
+    from win32api import GetFileVersionInfo, LOWORD, HIWORD
+    def get_version_number (filename):
+        """Return the version of a Windows DLL or EXE file
+        """
+        try:
+            info = GetFileVersionInfo (filename, "\\")
+            ms = info['FileVersionMS']
+            ls = info['FileVersionLS']
+            return HIWORD (ms), LOWORD (ms), HIWORD (ls), LOWORD (ls)
+        except:
+            return None
