@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: comscan.py 2509 2005-09-12 05:23:15Z djpham $
+### $Id: comscan.py 3932 2007-01-24 03:38:33Z djpham $
 
 
 """Detect and enumerate com(serial) ports
@@ -49,7 +49,7 @@ wW   driverdescription  string   some generic description of the driver
   L  driver             string   the driver name from /proc/devices (eg ttyS or ttyUSB)
 """
 
-version="$Revision: 2509 $"
+version="$Revision: 3932 $"
 
 import sys
 import os
@@ -192,8 +192,8 @@ def _comscanwindows():
     k=r"SYSTEM\CurrentControlSet\Services"
     for service in reg.safegetchildren(k):
         # we will just take largest number
-        count=reg.safegetvalue(k+"\\"+service+"\\Enum", "Count", 0)
-        next=reg.safegetvalue(k+"\\"+service+"\\Enum", "NextInstance", 0)
+        count=int(reg.safegetvalue(k+"\\"+service+"\\Enum", "Count", 0))
+        next=int(reg.safegetvalue(k+"\\"+service+"\\Enum", "NextInstance", 0))
         for id in range(max(count,next)):
             hw=reg.safegetvalue(k+"\\"+service+"\\Enum", `id`)
             if hw is None:
@@ -378,6 +378,7 @@ def _comscanlinux(maxnum=9):
         ("/dev/cua", "Standard serial port", "serial"), 
         ("/dev/ttyUSB", "USB to serial convertor", "serial"),
         ("/dev/ttyACM", "USB modem", "modem"),
+	("/dev/rfcomm", "Bluetooth", "modem"),
         ("/dev/usb/ttyUSB", "USB to serial convertor", "serial"), 
         ("/dev/usb/tts/", "USB to serial convertor", "serial"),
         ("/dev/usb/acm/", "USB modem", "modem"),
