@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: csv_calendar.py 3620 2006-10-20 03:50:58Z djpham $
+### $Id: csv_calendar.py 4179 2007-04-03 01:07:57Z djpham $
 
 "Deals with CSV calendar import/export stuff"
 
@@ -415,7 +415,7 @@ class CSVImportDialog(common_calendar.PreviewDialog):
         ('alarm', 'Alarm', 80, common_calendar.bp_alarm_str),
         ('categories', 'Category', 150, common_calendar.category_str)
         ]
-    ID_ADD=wx.NewId()
+
     def __init__(self, parent, id, title):
         self.__oc=CSVCalendarImportData()
         common_calendar.PreviewDialog.__init__(self, parent, id, title,
@@ -444,6 +444,7 @@ class CSVImportDialog(common_calendar.PreviewDialog):
         hbs.Add(wx.Button(self, id_import, 'Import'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs.Add(wx.Button(self, wx.ID_OK, 'Replace All'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs.Add(wx.Button(self, self.ID_ADD, 'Add'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
+        hbs.Add(wx.Button(self, self.ID_MERGE, 'Merge'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs.Add(wx.Button(self, wx.ID_CANCEL, 'Cancel'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         id_filter=wx.NewId()
         hbs.Add(wx.Button(self, id_filter, 'Filter'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)       
@@ -451,7 +452,8 @@ class CSVImportDialog(common_calendar.PreviewDialog):
         main_bs.Add(hbs, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         wx.EVT_BUTTON(self, id_import, self.OnImport)
         wx.EVT_BUTTON(self, id_filter, self.OnFilter)
-        wx.EVT_BUTTON(self, self.ID_ADD, self.OnAdd)
+        wx.EVT_BUTTON(self, self.ID_ADD, self.OnEndModal)
+        wx.EVT_BUTTON(self, self.ID_MERGE, self.OnEndModal)
         wx.EVT_BUTTON(self, wx.ID_HELP, lambda *_: wx.GetApp().displayhelpid(helpids.ID_DLG_CALENDAR_IMPORT))
 
     def OnImport(self, evt):
@@ -480,8 +482,8 @@ class CSVImportDialog(common_calendar.PreviewDialog):
             self.__oc.set_filter(dlg.get())
             self.populate(self.__oc.get_display_data())
 
-    def OnAdd(self, evt):
-        self.EndModal(self.ID_ADD)
+    def OnEndModal(self, evt):
+        self.EndModal(evt.GetId())
 
     def get(self):
         return self.__oc.get()
