@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: database.py 3729 2006-12-05 22:16:52Z djpham $
+### $Id: database.py 3990 2007-02-12 23:11:46Z djpham $
 
 """Interface to the database"""
 
@@ -255,7 +255,8 @@ def ExclusiveWrapper(method):
         self.excounter+=1
         self.transactionwrite=False
         if self.excounter==1:
-            print "BEGIN EXCLUSIVE TRANSACTION"
+            if TRACE:
+                print "BEGIN EXCLUSIVE TRANSACTION"
             self.cursor.execute("BEGIN EXCLUSIVE TRANSACTION")
             self._schemacache={}
         try:
@@ -279,7 +280,8 @@ def ExclusiveWrapper(method):
                         cmd="ROLLBACK TRANSACTION"
                     else:
                         cmd="END TRANSACTION"
-                print cmd
+                if TRACE:
+                    print cmd
                 self.cursor.execute(cmd)
                 
     setattr(_transactionwrapper, "__doc__", getattr(method, "__doc__"))
@@ -300,7 +302,22 @@ class IntegrityCheckFailed(Exception): pass
 
 class Database:
 
-    def __init__(self, filename):
+    def __del__(self):
+        # connections have to be closed now
+        self.connection.close(True)
+
+    def __init__(self, filename, virtualtables=None):
+        """
+        @param filename: database filename
+        @param virtualtables: a list of dict specifying the virtual tables
+            Each dict is expected to have the following keys:
+            'tablename': the name of the virtual table
+            'modulename': the name of the module that implements this virtual
+                table
+            'moduleclass': the ModuleBase subclass that implements this
+                virtual table
+            'args': arguments passed to instantiaion of the module class
+        """
         self.connection=apsw.Connection(filename)
         self.cursor=self.connection.cursor()
         # first tell sqlite to use the pre 3.4 format.  this will allow downgrades
@@ -327,6 +344,16 @@ class Database:
         if TRACE:
             self.cursor.setexectrace(self._sqltrace)
             self.cursor.setrowtrace(self._rowtrace)
+        if virtualtables is not None:
+            # virtual tables are specified
+            for vtable in virtualtables:
+                # register the module
+                self.connection.createmodule(vtable['modulename'],
+                                             vtable['moduleclass'](*vtable['args']))
+                if not self.doestableexist(vtable['tablename']):
+                    # and declare the virtual table
+                    self.sql('CREATE VIRTUAL TABLE %s USING %s;'%(idquote(vtable['tablename']),
+                                                                  idquote(vtable['modulename'])))
 
     def _sqltrace(self, cmd, bindings):
         print "SQL:",cmd
@@ -472,7 +499,7 @@ class Database:
                     continue
                 assert False, "You can't possibly get here!"
             if len(creates):
-                self._altertable(tablename, creates, createindex=1)
+                self._altertable(tablename, creates, [], createindex=1)
 
         # write out indirect values
         dbtkeys=self.getcolumns(tablename)
@@ -535,7 +562,7 @@ class Database:
         # are any missing?
         missing=[k for k in datakeys if k not in dbkeys]
         if len(missing):
-            self._altertable(tablename, [(m,"valueBLOB") for m in missing], createindex=2)
+            self._altertable(tablename, [(m,"valueBLOB") for m in missing], [], createindex=2)
         # for each row we now work out the indirect information
         for r in indirects:
             res=tablename+","
@@ -618,10 +645,12 @@ class Database:
         # now get the indirects
         for name,values in indirects.iteritems():
             for uid,v,type in values:
-                if type=="indirectBLOB":
-                    res[uid][name]=self._getindirect(v)
-                else:
-                    res[uid][name]=self._getindirect(v)[0]
+                fieldvalue=self._getindirect(v)
+                if fieldvalue:
+                    if type=="indirectBLOB":
+                        res[uid][name]=fieldvalue
+                    else:
+                        res[uid][name]=fieldvalue[0]
         return res
 
     def _getindirect(self, what):
@@ -644,42 +673,42 @@ class Database:
                     continue
                 assert type=="indirectBLOB" or type=="indirectdictBLOB"
                 assert False, "indirect in indirect not handled"
-            assert len(record)
+            assert len(record),"Database._getindirect has zero len record"
             res.append(record)
-        assert len(res)
+        assert len(res), "Database._getindirect has zero len res"
         return res
         
-    def _altertable(self, tablename, columnstoadd, createindex=0):
-        """Alters the named table by adding the listed columns
+    def _altertable(self, tablename, columnstoadd, columnstodel, createindex=0):
+        """Alters the named table by deleting the specified columns, and
+        adding the listed columns
 
         @param tablename: name of the table to alter
         @param columnstoadd: a list of (name,type) of the columns to add
+        @param columnstodel: a list name of the columns to delete
         @param createindex: what sort of index to create.  0 means none, 1 means on just __uid__ and 2 is on all data columns
         """
         # indexes are automatically dropped when table is dropped so we don't need to
-        dbtkeys=self.getcolumns(tablename)
+        dbtkeys=[x for x in self.getcolumns(tablename) \
+                 if x[1] not in columnstodel]
         # clean out cache entry since we are about to invalidate it
         del self._schemacache[tablename]
         self.transactionwrite=True
-        cmd=["create", "temporary", "table", idquote("backup_"+tablename), "("]
-        for _,n,t in dbtkeys:
-            if cmd[-1]!="(":
-                cmd.append(",")
-            cmd.append(idquote(n))
-            cmd.append(t)
-        cmd.append(")")
+        cmd=["create", "temporary", "table", idquote("backup_"+tablename),
+             "(",
+             ','.join(['%s %s'%(idquote(n), t) for _,n,t in dbtkeys]),
+             ")"]
         self.sql(" ".join(cmd))
         # copy the values into the temporary table
-        self.sql("insert into %s select * from %s" % (idquote("backup_"+tablename), idquote(tablename)))
+        self.sql("insert into %s select %s from %s" % (idquote("backup_"+tablename),
+                                                       ','.join([idquote(n) for _,n,_ in dbtkeys]),
+                                                       idquote(tablename)))
         # drop the source table
         self.sql("drop table %s" % (idquote(tablename),))
         # recreate the source table with new columns
         del cmd[1] # remove temporary
         cmd[2]=idquote(tablename) # change tablename
-        del cmd[-1] # remove trailing )
-        for n,t in columnstoadd:
-            cmd.extend((',', idquote(n), t))
-        cmd.append(')')
+        cmd[-2]=','.join(['%s %s'%(idquote(n), t) for _,n,t in dbtkeys]+\
+                         ['%s %s'%(idquote(n), t) for n,t in columnstoadd]) # new list of columns
         self.sql(" ".join(cmd))
         # create index if needed
         if createindex:
@@ -698,12 +727,9 @@ class Database:
                 raise ValueError("bad createindex "+`createindex`)
             self.sql(" ".join(cmd))
         # put values back in
-        cmd=["insert into", idquote(tablename), '(']
-        for _,n,_ in dbtkeys:
-            if cmd[-1]!="(":
-                cmd.append(",")
-            cmd.append(idquote(n))
-        cmd.extend([")", "select * from", idquote("backup_"+tablename)])
+        cmd=["insert into", idquote(tablename), '(',
+             ','.join([idquote(n) for _,n,_ in dbtkeys]),
+             ")", "select * from", idquote("backup_"+tablename)]
         self.sql(" ".join(cmd))
         self.sql("drop table "+idquote("backup_"+tablename))
 
@@ -849,6 +875,141 @@ class Database:
                 res[tt]['add']+=1
         return res
 
+class ModuleBase(object):
+    """Base class to implement a specific Virtual Table module with apsw.
+    For more info:
+    http://www.sqlite.org/cvstrac/wiki/wiki?p=VirtualTables
+    http://www.sqlite.org/cvstrac/wiki/wiki?p=VirtualTableMethods
+    http://www.sqlite.org/cvstrac/wiki/wiki?p=VirtualTableBestIndexMethod
+    """
+    def __init__(self, field_names):
+        self.connection=None
+        self.table_name=None
+        # the first field is ALWAYS __rowid__ to be consistent with Database
+        self.field_names=('__rowid__',)+field_names
+    def Create(self, connection, modulename, databasename, vtablename, *args):
+        """Called when the virtual table is created.
+        @param connection: an instance of apsw.Connection
+        @param modulename: string name of the module being invoked
+        @param databasename: string name of this database
+        @param vtablename: string name of this new virtual table
+        @param args: additional arguments sent from the CREATE VIRTUAL TABLE
+            statement
+        @returns: a tuple of 2 values: an sql string describing the table, and
+            an object implementing it: Me!
+        """
+        self.table_name=vtablename
+        fields=['__rowid__ integer primary key']
+        for field in self.field_names[1:]:
+            fields.append(idquote(field)+' valueBLOB')
+        fields='(%s)'%','.join(fields)
+        return ('create table %s %s;'%(idquote(vtablename), fields), self)
+
+    def Connect(self, connection, modulename, databasename, vtablename, *args):
+        """Connect to an existing virtual table, by default it is identical
+        to Create
+        """
+        return self.Create(connection, modulename, databasename, vtablename,
+                           *args)
+
+    def Destroy(self):
+        """Release a connection to a virtual table and destroy the underlying
+        table implementation.  By default, we do nothing.
+        """
+        pass
+    def Disconnect(self):
+        """Release a connection to a virtual table.  By default, we do nothing.
+        """
+        pass
+
+    def BestIndex(self, constraints, orderby):
+        """Provide information on how to best access this table.
+        Must be overriden by subclass.
+        @param constraints: a tuple of (column #, op) defining a constraints
+        @param orderby: a tuple of (column #, desc) defining the order by
+        @returns a tuple of up to 5 values:
+            0: aConstraingUsage: a tuple of the same size as constraints.
+                Each item is either None, argv index(int), or (argv index, omit(Bool)).
+            1: idxNum(int)
+            2: idxStr(string)
+            3: orderByConsumed(Bool)
+            4: estimatedCost(float)
+        """
+        raise NotImplementedError
+
+    def Begin(self):
+        pass
+    def Sync(self):
+        pass
+    def Commit(self):
+        pass
+    def Rollback(self):
+        pass
+
+    def Open(self):
+        """Create/prepare a cursor used for subsequent reading.
+        @returns: the implementor object: Me!
+        """
+        return self
+    def Close(self):
+        """Close a cursor previously created by Open
+        By default, do nothing
+        """
+        pass
+    def Filter(self, idxNum, idxStr, argv):
+        """Begin a search of a virtual table.
+        @param idxNum: int value passed by BestIndex
+        @param idxStr: string valued passed by BestIndex
+        @param argv: constraint parameters requested by BestIndex
+        @returns: None
+        """
+        raise NotImplementedError
+    def Eof(self):
+        """Determines if the current cursor points to a valid row.
+        The Sqlite doc is wrong on this.
+        @returns: True if NOT valid row, False otherwise
+        """
+        raise NotImplementedError
+    def Column(self, N):
+        """Find the value for the N-th column of the current row.
+        @param N: the N-th column
+        @returns: value of the N-th column
+        """
+        raise NotImplementedError
+    def Next(self):
+        """Move the cursor to the next row.
+        @returns: None
+        """
+        raise NotImplementedError
+    def Rowid(self):
+        """Return the rowid of the current row.
+        @returns: the rowid(int) of the current row.
+        """
+        raise NotImplementedError
+    def UpdateDeleteRow(self, rowid):
+        """Delete row rowid
+        @param rowid:
+        @returns: None
+        """
+        raise NotImplementedError
+    def UpdateInsertRow(self, rowid, fields):
+        """Insert a new row of data into the table
+        @param rowid: if not None, use this rowid.  If None, create a new rowid
+        @param fields: a tuple of the field values in the order declared in
+            Create/Connet
+        @returns: rowid of the new row.
+        """
+        raise NotImplementedError
+    def UpdateChangeRow(self, rowid, newrowid, fields):
+        """Change the row of the current rowid with the new rowid and new values
+        @param rowid: rowid of the current row
+        @param newrowid: new rowid
+        @param fields: a tuple of the field values in the order declared in
+            Create/Connect
+        @returns: rowid of the new row
+        """
+        raise NotImplementedError
+
 if __name__=='__main__':
     import common
     import sys
