@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: filesystem.py 3518 2006-08-16 03:04:25Z djpham $
+### $Id: filesystem.py 4215 2007-05-09 01:00:41Z djpham $
 
 """The main gui code for BitPim"""
 
@@ -56,7 +56,7 @@ class FileSystemView(wx.SplitterWindow, widgets.BitPimWidget):
         self.tree=FileSystemDirectoryView(mainwindow, self, wx.NewId(), style=(wx.TR_DEFAULT_STYLE|wx.TR_NO_LINES)&~wx.TR_TWIST_BUTTONS)
         self.list=FileSystemFileView(mainwindow, self, wx.NewId())
         self.sash_pos=mainwindow.config.ReadInt("filesystemsplitterpos", 200)
-        self.update_sash=True
+        self.update_sash=False
         self.SplitVertically(self.tree, self.list, self.sash_pos)
         self.SetMinimumPaneSize(20)
         wx.EVT_SPLITTER_SASH_POS_CHANGED(self, id, self.OnSplitterPosChanged)
@@ -493,6 +493,7 @@ class FileSystemDirectoryView(wx.TreeCtrl):
         wx.EVT_MENU(self.dirmenu, guihelper.ID_FV_OFFLINEPHONE, parent.OnPhoneOffline)
         wx.EVT_MENU(self.dirmenu, guihelper.ID_FV_REBOOTPHONE, parent.OnPhoneReboot)
         wx.EVT_MENU(self.dirmenu, guihelper.ID_FV_MODEMMODE, parent.OnModemMode)
+        wx.EVT_RIGHT_DOWN(self, self.OnRightDown)
         wx.EVT_RIGHT_UP(self, self.OnRightUp)
         self.image_list=wx.ImageList(16, 16)
         self.img_dir=self.image_list.Add(wx.ArtProvider_GetBitmap(guihelper.ART_FOLDER,
@@ -611,6 +612,10 @@ class FileSystemDirectoryView(wx.TreeCtrl):
             self.SelectItem(self.item)
             self.PopupMenu(self.genericmenu, pt)
                     
+    def OnRightDown(self, _):
+        # You have to capture right down otherwise it doesn't feed you right up
+        pass
+
     def OnItemSelected(self,_):
         if not self.dragging and not self.first_time:
             item=self.GetSelection()
