@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: fileview.py 3545 2006-08-31 20:21:31Z djpham $
+### $Id: fileview.py 4226 2007-05-09 21:21:04Z djpham $
 
 
 ###
@@ -29,6 +29,8 @@ import widgets
 import guiwidgets
 import shutil
 import database
+import helpids
+import tempfile
 
 
 basename=common.basename
@@ -39,8 +41,9 @@ getext=common.getext
 #-------------------------------------------------------------------------------
 class MediaDataObject(database.basedataobject):
     # modified_datatime is unix time
-    _knownproperties=['name', 'origin', 'index', 'mediadata', 'timestamp']
+    _knownproperties=['name', 'origin', 'index', 'timestamp']
     _knownlistproperties=database.basedataobject._knownlistproperties.copy()
+    _knownlistproperties.update( { 'mediadata': ['data'] })
     def __init__(self, data=None):
         if data is None or not isinstance(data, MediaEntry):
             return;
@@ -56,10 +59,20 @@ class MediaEntry(object):
         self._create_id()
 
     def get(self):
-        return copy.deepcopy(self._data, {})
+        res=copy.deepcopy(self._data, None, {})
+        # account for the medidadata field
+        if res.has_key('mediadata'):
+            if res['mediadata'] is not None:
+                res['mediadata']=[{'data': buffer(res['mediadata']) }]
+            else:
+                del res['mediadata']
+        return res
     def set(self, d):
         self._data={}
         self._data.update(d)
+        # check for mediadata
+        if d.get('mediadata', None) is not None:
+            self._data['mediadata']=str(d['mediadata'][0]['data'])
 
     def get_db_dict(self):
         return self.get()
@@ -110,9 +123,7 @@ class MediaEntry(object):
     origin=property(fget=_get_origin, fset=_set_origin)
 
     def _get_mediadata(self):
-        if self._data.has_key('mediadata'):
-            return self._data.get('mediadata', '')
-        return None
+        return self._data.get('mediadata', None)
     def _set_mediadata(self, v):
         if v is not None:
             self._set_or_del('mediadata', v, [])
@@ -185,17 +196,17 @@ class MyFileDropTarget(wx.FileDropTarget):
     def OnDragOver(self, x, y, d):
         if self.drag_over:
             return self.target.OnDragOver(x,y,d)
-        return wx.FileDropTarget.base_OnDragOver(self, x, y, d)
+        return wx.FileDropTarget.OnDragOver(self, x, y, d)
 
     def OnEnter(self, x, y, d):
         if self.enter_leave:
             return self.target.OnEnter(x,y,d)
-        return wx.FileDropTarget.base_OnEnter(self, x, y, d)
+        return wx.FileDropTarget.OnEnter(self, x, y, d)
 
     def OnLeave(self):
         if self.enter_leave:
             return self.target.OnLeave()
-        return wx.FileDropTarget.base_OnLeave(self)
+        return wx.FileDropTarget.OnLeave(self)
 
 class FileView(wx.Panel, widgets.BitPimWidget):
 
@@ -219,10 +230,13 @@ class FileView(wx.Panel, widgets.BitPimWidget):
     maxlen=-1  # set via phone profile
     # acceptable characters in a filename
     filenamechars=None # set via phone profile
+    # Default Help page, children can override
+    helpid=helpids.ID_TAB_MEDIA
 
     def __init__(self, mainwindow, parent, media_root, watermark=None):
         wx.Panel.__init__(self,parent,style=wx.CLIP_CHILDREN)
-
+        # adjust the DB to accommodate the new schema if necessary
+        self._fixupdb(mainwindow.database)
         # item attributes
         if self.item_selection_brush is None:
             self.item_selection_brush=wx.TheBrushList.FindOrCreateBrush("MEDIUMPURPLE2", wx.SOLID)
@@ -288,8 +302,8 @@ class FileView(wx.Panel, widgets.BitPimWidget):
         self.motionpos=None
         wx.EVT_MOUSE_EVENTS(self.aggdisp, self.OnMouseEvent)
         self.tipwindow=None
-        if guihelper.IsMSWindows():
-            # turn on drag-and-drag for windows
+        if True: # guihelper.IsMSWindows() or guihelper.IsGtk():
+            # turn on drag-and-drag for all platforms
             wx.EVT_MOTION(self.aggdisp, self.OnStartDrag)
 
         # Menus
@@ -490,9 +504,7 @@ class FileView(wx.Panel, widgets.BitPimWidget):
         wx.BeginBusyCursor()
         item=self.GetSelectedItems()[0]
         me=self._data[self.database_key][item.key]
-        fname=self.filename(me)
-        if not os.path.isfile(fname):
-            return
+        fname=self._gettempfile(me)
         if guihelper.IsMac():
             import findertools
             findertools.launch(fname)
@@ -504,8 +516,8 @@ class FileView(wx.Panel, widgets.BitPimWidget):
             wx.Execute(cmd, wx.EXEC_ASYNC)
         wx.EndBusyCursor()
 
-    if guihelper.IsMSWindows():
-        # drag-and-drop files only works in Windows
+    if True: # guihelper.IsMSWindows() or guihelper.IsGtk():
+        # drag-and-drop files should work on all platforms
         def OnStartDrag(self, evt):
             evt.Skip()
             if not evt.LeftIsDown():
@@ -517,7 +529,7 @@ class FileView(wx.Panel, widgets.BitPimWidget):
             file_names=wx.FileDataObject()
             for item in items:
                 me=self._data[self.database_key][item.key]
-                fname=self.filename(me)
+                fname=self._gettempfile(me)
                 if not os.path.isfile(fname):
                     continue
                 file_names.AddFile(fname)
@@ -529,7 +541,7 @@ class FileView(wx.Panel, widgets.BitPimWidget):
             # can't trust result returned by DoDragDrop
             for item in items:
                 me=self._data[self.database_key][item.key]
-                fname=self.filename(me)
+                fname=self._gettempfile(me)
                 if not os.path.isfile(fname):
                     item.RemoveFromIndex()
 
@@ -605,28 +617,6 @@ class FileView(wx.Panel, widgets.BitPimWidget):
         self.aggdisp.SelectAll()
         self.item_list.SelectAll()
 
-    def EndSelectedFilesContext(self, context, deleteitems=False):
-        # We have a fun additional problem.  By default Windows
-        # returns a code that it is copying, when in fact it is
-        # moving.  Consequently we do a delete if either the
-        # source file is gone, or deleteitems is true
-        if not deleteitems:
-            for item in context:
-                me=self._data[self.database_key][item.key]
-                fname=self.filename(me)
-                if not os.path.exists(fname):
-                    deleteitems=True
-                    break
-        if deleteitems:
-            for item in context:
-                me=self._data[self.database_key][item.key]
-                fname=self.filename(me)
-                if os.path.exists(fname):
-                    os.remove(fname)
-            for item in context:
-                item.RemoveFromIndex()
-            self.OnRefresh()
-
     def OnSave(self, _):
         # If one item is selected we ask for a filename to save.  If
         # multiple then we ask for a directory, and users don't get
@@ -649,7 +639,7 @@ class FileView(wx.Panel, widgets.BitPimWidget):
             dlg=wx.DirDialog(self, "Save items to", style=wx.DD_DEFAULT_STYLE|wx.DD_NEW_DIR_BUTTON)
             if dlg.ShowModal()==wx.ID_OK:
                 for item in items:
-                    fname=self.filename(item)
+                    fname=item.name.encode(media_codec)
                     fname=os.path.join(dlg.GetPath(), basename(fname))
                     file(fname, 'wb').write(self._data[item.datakey][item.key].mediadata)
                     if self._data[item.datakey][item.key].timestamp!=None:
@@ -666,7 +656,7 @@ class FileView(wx.Panel, widgets.BitPimWidget):
             file_names=wx.FileDataObject()
             for item in items:
                 me=self._data[self.database_key][item.key]
-                fname=self.filename(me)
+                fname=self._gettempfile(me)
                 if not os.path.isfile(fname):
                     continue
                 file_names.AddFile(fname)
@@ -676,27 +666,62 @@ class FileView(wx.Panel, widgets.BitPimWidget):
         def CanCopy(self):
             return len(self.GetSelectedItems())
 
-    def OnPaste(self, _=None):
-        if not wx.TheClipboard.Open():
-            # can't access the clipboard
-            return
-        if wx.TheClipboard.IsSupported(wx.DataFormat(wx.DF_FILENAME)):
-            file_names=wx.FileDataObject()
-            has_data=wx.TheClipboard.GetData(file_names)
-        else:
-            has_data=False
-        wx.TheClipboard.Close()
-        if has_data:
-            self.OnAddFiles(file_names.GetFilenames())
+    if guihelper.IsGtk():
+        # Gtk just pastes the file names as text onto the Clipboard
+        def OnPaste(self, _=None):
+            if not wx.TheClipboard.Open():
+                # can't access the clipboard
+                return
+            if wx.TheClipboard.IsSupported(wx.DataFormat(wx.DF_UNICODETEXT)):
+                file_names=wx.TextDataObject()
+                has_data=wx.TheClipboard.GetData(file_names)
+            else:
+                has_data=False
+            wx.TheClipboard.Close()
+            if has_data:
+                # collect file names if any.
+                _names=[x for x in file_names.GetText().split('\n') \
+                        if os.path.isfile(x) ]
+                if _names:
+                    self.OnAddFiles(_names)
+        def CanPaste(self):
+            """ Return True if can accept clipboard data, False otherwise
+            """
+            if not wx.TheClipboard.Open():
+                return False
+            r=wx.TheClipboard.IsSupported(wx.DataFormat(wx.DF_UNICODETEXT))
+            if r:
+                file_names=wx.TextDataObject()
+                r=wx.TheClipboard.GetData(file_names)
+                if r:
+                    for _name in file_names.GetText().split('\n'):
+                        if not os.path.isfile(_name):
+                            r=False
+                            break
+            wx.TheClipboard.Close()
+            return r
+    else:
+        def OnPaste(self, _=None):
+            if not wx.TheClipboard.Open():
+                # can't access the clipboard
+                return
+            if wx.TheClipboard.IsSupported(wx.DataFormat(wx.DF_FILENAME)):
+                file_names=wx.FileDataObject()
+                has_data=wx.TheClipboard.GetData(file_names)
+            else:
+                has_data=False
+            wx.TheClipboard.Close()
+            if has_data:
+                self.OnAddFiles(file_names.GetFilenames())
 
-    def CanPaste(self):
-        """ Return True if can accept clipboard data, False otherwise
-        """
-        if not wx.TheClipboard.Open():
-            return False
-        r=wx.TheClipboard.IsSupported(wx.DataFormat(wx.DF_FILENAME))
-        wx.TheClipboard.Close()
-        return r
+        def CanPaste(self):
+            """ Return True if can accept clipboard data, False otherwise
+            """
+            if not wx.TheClipboard.Open():
+                return False
+            r=wx.TheClipboard.IsSupported(wx.DataFormat(wx.DF_FILENAME))
+            wx.TheClipboard.Close()
+            return r
 
     def CanDelete(self):
         if len(self.GetSelectedItems()):
@@ -706,11 +731,6 @@ class FileView(wx.Panel, widgets.BitPimWidget):
     def OnDelete(self,_):
         items=self.GetSelectedItems()
         for item in items:
-            try:
-                # try to remove the media file
-                os.remove(self.filename(item))
-            except:
-                pass
             item.RemoveFromIndex()
         self.OnRefresh()
 
@@ -744,7 +764,28 @@ class FileView(wx.Panel, widgets.BitPimWidget):
         dict[self.database_key][entry.id]=entry
         self.modified=True
 
-    def filename(self, item):
+    def _fixupdb(self, db):
+        # fixup the database to accommodate the new schema
+        adjustflg=False
+        for _,_name,_type in db.getcolumns(self.database_key):
+            if _name=='mediadata' and _type!='indirectBLOB':
+                # old schema, need to adjust
+                adjustflg=True
+                break
+        # adjust the table: replace the mediadata field
+        if adjustflg:
+            db._altertable(self.database_key, [('mediadata', 'indirectBLOB')],
+                           ['mediadata'], 1)
+
+    def _gettempfile(self, item):
+        # store the the media data in a temporary file and return the full file
+        # path
+        filename=os.path.join(tempfile.gettempdir(),
+                              item.name.encode(media_codec))
+        file(filename, 'wb').write(item.mediadata)
+        return filename
+
+    def _filename(self, item):
         # return the filename associated with a media file
         if hasattr(item, 'origin'):
             _origin=item.origin
@@ -763,18 +804,6 @@ class FileView(wx.Panel, widgets.BitPimWidget):
             # the media data does not go into the actual database, we store it 
             # in a regular file to minimise the database size, it 
             # gets very big if the data is stored in it and starts to get slow.
-            if db_rr[k].has_key('mediadata'):
-                fname=self.filename(db_rr[k])
-                # create the directory for the origin
-                dir_name,_=os.path.split(fname)
-                try:
-                    os.makedirs(dir_name)
-                except:
-                    pass
-                if not os.path.isdir(dir_name):
-                    raise Exception("Unable to create media directory "+dir_name)
-                file(fname, 'wb').write(db_rr[k]['mediadata'])
-                del db_rr[k]['mediadata']
         database.ensurerecordtype(db_rr, mediaobjectfactory)
         self.mainwindow.database.savemajordict(self.database_key, db_rr)
 
@@ -786,13 +815,15 @@ class FileView(wx.Panel, widgets.BitPimWidget):
         for k,e in dict.items():
             ce=MediaEntry()
             ce.set_db_dict(e)
-            try:
-                ce.mediadata=file(self.filename(ce), 'rb').read()
-            except:
-                # abandon data that has no file it probably means that 
-                # blobs directory is corrupted, maybe the user deleted
-                # the file themselves
-                ce.mediadata=None
+            if ce.mediadata is None:
+                # try reading the data from the "old" way
+                try:
+                    ce.mediadata=file(self._filename(ce), 'rb').read()
+                except:
+                    # abandon data that has no file it probably means that 
+                    # blobs directory is corrupted, maybe the user deleted
+                    # the file themselves
+                    pass
             r[ce.id]=ce
         result.update({ self.database_key: r})
         return result
@@ -932,17 +963,8 @@ class FileView(wx.Panel, widgets.BitPimWidget):
         return result
 
     def delete_old_media(self):
-        try:
-            if os.path.isdir(self.thedir):
-                # delete all files we don't know about
-                for f in os.listdir(self.thedir):
-                    # delete them all except windows magic ones which we ignore
-                    if f.lower() not in self.skiplist:
-                        os.remove(os.path.join(self.thedir, f))
-                    if not len(os.listdir(self.thedir)):
-                        os.rmdir(self.thedir)
-        except:
-            pass
+        # No longer do this since it messes up the virtual tables setup!
+        pass
 
     def OnDropFiles(self, _, dummy, filenames):
         # There is a bug in that the most recently created tab
@@ -983,21 +1005,12 @@ class FileView(wx.Panel, widgets.BitPimWidget):
         if dlg.ShowModal()==wx.ID_OK:
             new_name=dlg.GetValue()
             if len(new_name) and new_name!=old_name:
-                old_fname=self.filename(items[0])
                 items[0].name=new_name
-                new_fname=self.filename(items[0])
-                try:
-                    # try renaming the file
-                    os.rename(old_fname, new_fname)
-                    # good to go with the rest
-                    items[0].RenameInIndex(new_name)
-                    pubsub.publish(pubsub.MEDIA_NAME_CHANGED,
-                                   data={ pubsub.media_change_type: self.media_notification_type,
-                                          pubsub.media_old_name: old_name,
-                                          pubsub.media_new_name: new_name })
-                except:
-                    # failed to rename
-                    items[0].name=old_name
+                items[0].RenameInIndex(new_name)
+                pubsub.publish(pubsub.MEDIA_NAME_CHANGED,
+                               data={ pubsub.media_change_type: self.media_notification_type,
+                                      pubsub.media_old_name: old_name,
+                                      pubsub.media_new_name: new_name })
         dlg.Destroy()
           
     def OnAddFiles(self,_):
@@ -1090,6 +1103,9 @@ class FileView(wx.Panel, widgets.BitPimWidget):
     def log(self, log_str):
         self.mainwindow.log(log_str)
 
+    def GetHelpID(self):
+        return self.helpid
+
 class FileViewDisplayItem(object):
 
     datakey="Someone forgot to set me"
