@@ -5,12 +5,11 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: gui.py 3793 2006-12-22 04:00:51Z djpham $
+### $Id: gui.py 4287 2007-06-12 02:33:21Z djpham $
 
-"""The main gui code for BitPim"""
+"""The main gui code for BitPim""" 
 
 # System modules
-import ConfigParser
 import thread, threading
 import Queue
 import time
@@ -55,11 +54,16 @@ import fileview
 import data_recording
 import analyser
 import t9editor
+import newdb_wiz
+import bp_config
 
 if guihelper.IsMSWindows():
     import win32api
     import win32con
     import win32gui
+    import msvcrt
+else:
+    import fcntl
 
 ###
 ### Used to check our threading
@@ -243,6 +247,8 @@ class MySplashScreen(wx.SplashScreen):
         self.goforit()
         evt.Skip()
 
+class BitPimExit(Exception):
+    pass
 
 class WorkerThreadFramework(threading.Thread):
     def __init__(self):
@@ -281,8 +287,9 @@ class WorkerThreadFramework(threading.Thread):
                     ex.gui_exc_info=sys.exc_info()
                 
             wx.PostEvent(self.dispatchto, HelperReturnEvent(resultcb, ex, res))
-            if isinstance(ex, SystemExit):
-                raise ex
+            if isinstance(ex, BitPimExit):
+                # gracefully end this thread!
+                break
 
     def progressminor(self, pos, max, desc=""):
         wx.PostEvent(self.dispatchto, HelperReturnEvent(self.dispatchto.progressminorcb, pos, max, desc))
@@ -302,102 +309,6 @@ class WorkerThreadFramework(threading.Thread):
             wx.PostEvent(self.dispatchto, HelperReturnEvent(self.dispatchto.logdatacb, str, data, klass,
                                                             data_type))
 
-###
-###  BitPim Config class
-###
-class Config(ConfigParser.ConfigParser):
-    _default_config_filename='.bitpim'
-
-    def __init__(self, config_file_name=None):
-        ConfigParser.ConfigParser.__init__(self)
-        # get/set path & filename
-        if config_file_name:
-            self._filename=os.path.abspath(config_file_name)
-            self._path=os.path.dirname(self._filename)
-        else:
-            self._path, self._filename=self._getdefaults()
-        # read in the config if exist
-        if self._filename:
-            try:
-                self.read([self._filename])
-            except:
-                # something is wrong with the config file, just bail
-                if __debug__:
-                    raise
-            self.Write('path', self._path)
-            self.Write('config', self._filename)
-
-    def _getdefaults(self):
-        # return the default path & config file name
-        # consistent with the previous BitPim way
-        if guihelper.IsMSWindows(): # we want subdir of my documents on windows
-            # nice and painful
-            from win32com.shell import shell, shellcon
-            try:
-                path=shell.SHGetFolderPath(0, shellcon.CSIDL_PERSONAL, None, 0)
-            except: # it will fail if path doesn't exist.  one example was a user
-                # putting my docs on an external usb drive that isn't plugged in
-                # when starting bitpim
-                path=r"c:\My BitPim Files"
-            path=os.path.join(path, "bitpim")
-        else:
-            path=os.path.expanduser("~/.bitpim-files")
-        return path,os.path.join(path, Config._default_config_filename)
-
-    def _expand(self, key):
-        # return a tuple of (section, option) based on the key
-        _l=key.split('/')
-        return (len(_l)>1 and '/'.join(_l[:-1]) or 'DEFAULT', _l[-1])
-        
-    def _check_section(self, section):
-        if section and section!='DEFAULT' and not self.has_section(section):
-            self.add_section(section)
-
-    def Read(self, key, default=''):
-        try:
-            return self.get(*self._expand(key))
-        except:
-            return default
-
-    def ReadInt(self, key, default=0):
-        _section,_option=self._expand(key)
-        try:
-            # first try for an int value
-            return self.getint(_section, _option)
-        except:
-            pass
-        try:
-            # then check for a bool value
-            return self.getboolean(_section, _option)
-        except:
-            # none found, return the default
-            return default
-
-    def ReadFloat(self, key, default=0.0):
-        try:
-            return self.getfloat(*self._expand(key))
-        except:
-            return default
-
-    def Write(self, key, value):
-        try:
-            _section,_option=self._expand(key)
-            if not _section:
-                _section='DEFAULT'
-            self._check_section(_section)
-            self.set(_section, _option, str(value))
-            self.write(file(self._filename, 'wb'))
-            return True
-        except:
-            return False
-    WriteInt=Write
-    WriteFloat=Write
-
-    def HasEntry(self, key):
-        return self.has_option(*self._expand(key))
-    def Flush(self):
-        pass
-
 ####
 #### Main application class.  Runs the event loop etc
 ####
@@ -419,8 +330,34 @@ class MainApp(wx.App):
         self.SAFEMODE=False
         codecs.register(phone_media_codec.search_func)
         self._config_filename=config_filename
-        wx.App.__init__(self, redirect=False, useBestVisual=True)
-        
+        wx.App.__init__(self, redirect=False,
+                        useBestVisual=not guihelper.IsGtk())
+
+    def lock_file(self, filename):
+        # if the file can be locked, lock it and return True.
+        # return False otherwise.
+        try:
+            self.lockedfile=file(filename, 'w')
+        except IOError:
+            # failed to create the file, just bail
+            self.lockedfile=None
+            return True
+        try:
+            if guihelper.IsMSWindows():
+                msvcrt.locking(self.lockedfile.fileno(),
+                               msvcrt.LK_NBLCK, 1)
+            else:
+                # Linux & Mac
+                fcntl.flock(self.lockedfile.fileno(),
+                            fcntl.LOCK_EX|fcntl.LOCK_NB)
+            return True
+        except IOError:
+            return False
+
+    def usingsamedb(self):
+        # using a simple file locking method
+        return not self.lock_file(os.path.join(self.config._path, '.lock'))
+
     def OnInit(self):
         self.made=False
         # Routine maintenance
@@ -436,7 +373,14 @@ class MainApp(wx.App):
         self.SetVendorName(cfgstr)
 
         # Establish config stuff
-        self.config=Config(self._config_filename)
+        self.config=bp_config.Config(self._config_filename)
+        # Check to see if we're the 2nd instance running on the same DB
+        if self.usingsamedb():
+            wx.MessageDialog(None,
+                             'Another copy of BitPim is using the same data dir:\n%s'%self.config._path,
+                             'BitPim Error',
+                             style=wx.OK|wx.ICON_ERROR).ShowModal()
+            return False
         # this is for wx native use, like the freaking help controller !
         self.wxconfig=wx.Config(cfgstr, style=wx.CONFIG_USE_LOCAL_FILE)
 
@@ -520,15 +464,16 @@ class MainApp(wx.App):
 
     def _setuphelp(self):
         """Does all the nonsense to get help working"""
-        if guihelper.IsMac():
+        if guihelper.IsMSWindows():
+            self.helpcontroller=True
+            return
+        elif guihelper.IsMac():
             # we use apple's help mechanism
             from Carbon import AH
             path=os.path.abspath(os.path.join(guihelper.resourcedirectory, "..", "..", ".."))
             # path won't exist if we aren't a bundle
             if  os.path.exists(path) and path.endswith(".app"):
-                print "registering help book for bundle",path
                 res=AH.AHRegisterHelpBook(path)
-                print "result was",res
                 self.helpcontroller=True
                 return
 
@@ -547,40 +492,41 @@ class MainApp(wx.App):
         # wx.HelpProvider_Set(provider)
 
     def displayhelpid(self, id):
+        """Display a specific Help Topic"""
+        if self.helpcontroller is None:
+            self._setuphelp()
+
         if guihelper.IsMSWindows():
             import win32help
             fname=guihelper.gethelpfilename()+".chm>Help"
             if id is None:
                 id=helpids.ID_WELCOME
             # display the topic
-            win32help.HtmlHelp(self.frame.GetHandle(), fname,
-                               win32help.HH_DISPLAY_TOPIC, id)
+            _hwnd=win32gui.GetDesktopWindow()
+            win32help.HtmlHelp(_hwnd, fname, win32help.HH_DISPLAY_TOPIC, id)
             # and sync the TOC
-            win32help.HtmlHelp(self.frame.GetHandle(), fname,
-                               win32help.HH_SYNC, id)
-            return
-        elif guihelper.IsMac():
-            if self.helpcontroller is None:
-                self._setuphelp()
-            if self.helpcontroller is True:
-                from Carbon import AH
-                res=AH.AHGotoPage('BitPim Help', id, None)
-                print "gotopage",id,"returned",res
-                return
+            win32help.HtmlHelp(_hwnd, fname, win32help.HH_SYNC, id)
+
+        elif guihelper.IsMac() and self.helpcontroller is True:
+            from Carbon import AH
+            res=AH.AHGotoPage('BitPim Help', id, None)
 
-        if self.helpcontroller is None:
-            self._setuphelp()
-        if id is None:
-            self.helpcontroller.DisplayContents()
         else:
-            self.helpcontroller.Display(id)
+            if id is None:
+                self.helpcontroller.DisplayContents()
+            else:
+                self.helpcontroller.Display(id)
 
     def makemainwindow(self):
         if self.made:
             return # already been called
         self.made=True
         # make the main frame
-        self.frame=MainWindow(None, -1, "BitPim", self.config)
+        title='BitPim'
+        name=self.config.Read('name', None)
+        if name:
+            title+=' - '+name
+        self.frame=MainWindow(None, -1, title, self.config)
         self.frame.Connect(-1, -1, EVT_CALLBACK, self.frame.OnCallback)
         if guihelper.IsMac():
             self.frame.MacSetMetalAppearance(True)
@@ -596,6 +542,9 @@ class MainApp(wx.App):
         self.ApplySafeMode()
         wx.CallAfter(self.CheckDetectPhone)
         wx.CallAfter(self.CheckUpdate)
+        # double-check the locked file
+        if self.lockedfile is None:
+            self.usingsamedb()
 
     update_delta={ 'Daily': 1, 'Weekly': 7, 'Monthly': 30 }
     def CheckUpdate(self):
@@ -711,7 +660,7 @@ class MainWindow(wx.Frame):
         ### Art
         # establish the custom art provider for custom icons
         # this is a global setting, so no need to call it for each toolbar
-        wx.ArtProvider_PushProvider(guihelper.ArtProvider())
+        wx.ArtProvider.PushProvider(guihelper.ArtProvider())
 
         # frame icon
         ib=wx.IconBundle()
@@ -766,9 +715,6 @@ class MainWindow(wx.Frame):
         menu.Append(guihelper.ID_EDITDELETEENTRY, "&Delete", "Delete currently selected entry")
         menu.Append(guihelper.ID_EDITRENAME, "&Rename\tF2", "Rename currently selected entry")
         menu.AppendSeparator()
-        menu.Append(guihelper.ID_EDITPHONEINFO,
-                    "Phone &Info", "Display Phone Information")
-        menu.AppendSeparator()
         menu.Append(guihelper.ID_EDITDETECT,
                     "D&etect Phone", "Auto Detect Phone")
         if guihelper.IsMac():
@@ -783,6 +729,9 @@ class MainWindow(wx.Frame):
         menu.Append(guihelper.ID_DATAGETPHONE, "Get Phone &Data ...", "Loads data from the phone")
         menu.Append(guihelper.ID_DATASENDPHONE, "&Send Phone Data ...", "Sends data to the phone")
         menu.Append(guihelper.ID_DATAHISTORICAL, "&Historical Data ...", "View Current & Historical Data")
+        menu.AppendSeparator()
+        menu.Append(guihelper.ID_DATANEWDB, 'Create New Storage ...',
+                    'Create a New BitPim Storage Area')
         menuBar.Append(menu, "&Data")
 
         menu=wx.Menu()
@@ -794,6 +743,9 @@ class MainWindow(wx.Frame):
         menu.AppendSeparator()
         menu.AppendCheckItem(guihelper.ID_VIEWFILESYSTEM, "View &Filesystem", "View filesystem on the phone")
         menu.AppendSeparator()
+        menu.Append(guihelper.ID_EDITPHONEINFO,
+                    "Phone &Info", "Display Phone Information")
+        menu.AppendSeparator()
         menu.Append(guihelper.ID_DR_SETTINGS, 'Data Recording',
                     'Data Recording Settings')
         menuBar.Append(menu, "&View")
@@ -805,7 +757,10 @@ class MainWindow(wx.Frame):
             menu.Append(guihelper.ID_HELPHELP, "&Help", "Help for the panel you are looking at")
         menu.Append(guihelper.ID_HELPTOUR, "&Tour", "Tour of BitPim")
         menu.Append(guihelper.ID_HELPCONTENTS, "&Contents", "Table of contents for the online help")
+        menu.Append(guihelper.ID_HELPHOWTOS, "H&owTos", "Help on how to do certain function")
+        menu.Append(guihelper.ID_HELPFAQ, "&FAQ", "Frequently Asked Questions")
         menu.Append(guihelper.ID_HELPSUPPORT, "&Support", "Getting support for BitPim")
+        menu.Append(guihelper.ID_HELPPHONE, "Your &Phone", "Help on specific phonemodel")
         if version.vendor=='official':
             menu.AppendSeparator()
             menu.Append(guihelper.ID_HELP_UPDATE, "&Check for Update", "Check for any BitPim Update")
@@ -871,6 +826,7 @@ class MainWindow(wx.Frame):
         wx.EVT_MENU(self, guihelper.ID_DATAGETPHONE, self.OnDataGetPhone)
         wx.EVT_MENU(self, guihelper.ID_DATASENDPHONE, self.OnDataSendPhone)
         wx.EVT_MENU(self, guihelper.ID_DATAHISTORICAL, self.tree.OnDataHistorical)
+        wx.EVT_MENU(self, guihelper.ID_DATANEWDB, self.OnNewDB)
         wx.EVT_MENU(self, guihelper.ID_VIEWCOLUMNS, self.tree.OnViewColumns)
         wx.EVT_MENU(self, guihelper.ID_VIEWPREVIEW, self.tree.OnViewPreview)
         wx.EVT_MENU(self, guihelper.ID_VIEWCLEARLOGS, self.tree.OnViewClearLogs)
@@ -885,9 +841,12 @@ class MainWindow(wx.Frame):
         wx.EVT_MENU(self, guihelper.ID_HELPABOUT, self.OnHelpAbout)
         wx.EVT_MENU(self, guihelper.ID_HELPHELP, self.OnHelpHelp)
         wx.EVT_MENU(self, guihelper.ID_HELPCONTENTS, self.OnHelpContents)
+        wx.EVT_MENU(self, guihelper.ID_HELPHOWTOS, self.OnHelpHowtos)
+        wx.EVT_MENU(self, guihelper.ID_HELPFAQ, self.OnHelpFAQ)
         wx.EVT_MENU(self, guihelper.ID_HELPSUPPORT, self.OnHelpSupport)
         wx.EVT_MENU(self, guihelper.ID_HELPTOUR, self.OnHelpTour)
         wx.EVT_MENU(self, guihelper.ID_HELP_UPDATE, self.OnCheckUpdate)
+        wx.EVT_MENU(self, guihelper.ID_HELPPHONE, self.OnHelpPhone)
         wx.EVT_MENU(self, guihelper.ID_EDITPHONEINFO, self.OnPhoneInfo)
         wx.EVT_MENU(self, guihelper.ID_EDITDETECT, self.OnDetectPhone)
         wx.EVT_MENU(self, guihelper.ID_AUTOSYNCSETTINGS, self.OnAutoSyncSettings)
@@ -939,6 +898,7 @@ class MainWindow(wx.Frame):
         wx.EVT_UPDATE_UI(self, guihelper.ID_EDITRENAME, self.tree.EditRenameUpdateUIEvent)
         wx.EVT_UPDATE_UI(self, guihelper.ID_VIEWLOGDATA, self.tree.ViewLogDataUIEvent)
         wx.EVT_UPDATE_UI(self, guihelper.ID_VIEWFILESYSTEM, self.tree.ViewFileSystemUIEvent)
+        wx.EVT_UPDATE_UI(self, guihelper.ID_HELPPHONE, self.OnHelpPhoneUpdateUI)
 
         # Retrieve saved settings... Use 90% of screen if not specified
         guiwidgets.set_size("MainWin", self, screenpct=90)
@@ -1084,12 +1044,11 @@ class MainWindow(wx.Frame):
         self.MakeCall( Request(self.wt.exit), Callback(self.OnCloseResults) )
 
     def OnCloseResults(self, exception, _):
-        assert isinstance(exception, SystemExit)
+        assert isinstance(exception, BitPimExit)
         # assume it worked
         if self._taskbar:
             self._taskbar.Destroy()
         self.Destroy()
-        wx.GetApp().ExitMainLoop()
 
     def OnIconize(self, evt):
         if evt.Iconized():
@@ -1110,17 +1069,17 @@ class MainWindow(wx.Frame):
     # about and help
 
     def OnHelpAbout(self,_):
-        import version
-
-        str="BitPim Version "+version.versionstring+" - "+version.vendor
-
-        d=wx.MessageDialog(self, str, "About BitPim", wx.OK|wx.ICON_INFORMATION)
-        d.ShowModal()
-        d.Destroy()
+        guiwidgets.show_about_dlg(self)
         
     def OnHelpHelp(self, _):
         wx.GetApp().displayhelpid(self.GetCurrentActiveWidget().GetHelpID())
 
+    def OnHelpHowtos(self, _):
+        wx.GetApp().displayhelpid(helpids.ID_HOWTOS)
+
+    def OnHelpFAQ(self, _):
+        wx.GetApp().displayhelpid(helpids.ID_FAQ)
+
     def OnHelpContents(self, _):
         wx.GetApp().displayhelpid(None)
 
@@ -1130,6 +1089,15 @@ class MainWindow(wx.Frame):
     def OnHelpTour(self, _=None):
         wx.GetApp().displayhelpid(helpids.ID_TOUR)
 
+    def OnHelpPhoneUpdateUI(self, event):
+        if self.phonemodule and hasattr(self.phonemodule.Phone, 'desc'):
+            event.SetText(self.phonemodule.Phone.desc)
+        else:
+            event.SetText('Phone')  
+        event.Enable(bool(hasattr(self.phonemodule.Phone, "helpid") and\
+                     self.phonemodule.Phone.helpid))
+    def OnHelpPhone(self, _):
+        wx.GetApp().displayhelpid(self.phonemodule.Phone.helpid)
     def DoCheckUpdate(self):
         s=update.check_update()
         if not len(s):
@@ -1365,6 +1333,9 @@ class MainWindow(wx.Frame):
     def update_cache_path(self):
         com_brew.file_cache.set_path(self.configpath)
 
+    def OnNewDB(self, _):
+        newdb_wiz.create_new_db(self, self.config)
+
     ### 
     ### Main bit for getting stuff from phone
     ###
@@ -1834,7 +1805,7 @@ class WorkerThread(WorkerThreadFramework):
             self.progressmajor(i, 2, "Shutting down helper thread")
             time.sleep(1)
         self.log("helper thread shut down")
-        raise SystemExit("helper thread shutdown")
+        raise BitPimExit("helper thread shutdown")
 
 
     def clearcomm(self):
