@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: guihelper.py 3620 2006-10-20 03:50:58Z djpham $
+### $Id: guihelper.py 4229 2007-05-10 22:51:46Z djpham $
 
 "Various helper routines for gui based code"
 
@@ -49,6 +49,7 @@ ID_EDITRENAME=1
 ID_DATAGETPHONE=1
 ID_DATASENDPHONE=1
 ID_DATAHISTORICAL=1
+ID_DATANEWDB=1
 ID_AUTOSYNCSETTINGS=1
 ID_AUTOSYNCEXECUTE=1
 ID_VIEWCOLUMNS=1
@@ -62,6 +63,9 @@ ID_HELPTOUR=1
 ID_HELPSUPPORT=1
 ID_HELP_UPDATE=1
 ID_HELPABOUT=1
+ID_HELPPHONE=1
+ID_HELPHOWTOS=1
+ID_HELPFAQ=1
 ID_DR_SETTINGS=1
 ID_FILEVIEW_THUMBNAIL=1
 ID_FILEVIEW_LIST=1
@@ -295,7 +299,11 @@ def GetOpenCommand(mimetypes, filename):
         ft=wx.TheMimeTypesManager.GetFileTypeFromMimeType(mt)
         if ft is None:
             continue
-        cmd=ft.GetOpenCommand(filename)
+        if IsGtk():
+            # protect file names with spaces
+            cmd=ft.GetOpenCommand('"%s"'%filename)
+        else:
+            cmd=ft.GetOpenCommand(filename)
         if cmd is not None and len(cmd):
             return cmd
     return None
