@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: guiwidgets.py 3793 2006-12-22 04:00:51Z djpham $
+### $Id: guiwidgets.py 4230 2007-05-10 22:52:21Z djpham $
 
 """Most of the graphical user interface elements making up BitPim"""
 
@@ -54,6 +54,7 @@ import widgets
 import phones
 import setphone_wizard
 import data_recording
+import xyaptu
 
 ###
 ### BitFling cert stuff
@@ -465,6 +466,16 @@ class ConfigDialog(wx.Dialog):
                                   allowNegative=False)
         gs.Add(self.splashscreen, pos=(_row, 1), flag=wx.ALIGN_CENTER_VERTICAL)
         _row+=1
+        # Developer's Console
+        if __debug__:
+            gs.Add(wx.StaticText(self, -1, 'Developer Console'),
+                   pos=(_row,0),
+                   flag=wx.ALIGN_CENTER_VERTICAL)
+            self.dev_console=wx.CheckBox(self, wx.NewId(),
+                                         'Display Developer Console')
+            gs.Add(self.dev_console, pos=(_row, 1),
+                   flag=wx.ALIGN_CENTER_VERTICAL)
+            _row+=1
         # bitfling
         if bitflingscan.IsBitFlingEnabled():
             self.SetupBitFlingCertVerification()
@@ -647,6 +658,8 @@ class ConfigDialog(wx.Dialog):
                 self.taskbaricon1.Enable(False)
         self.autodetect_start.SetValue(self.mw.config.ReadInt("autodetectstart", 0))
         self.splashscreen.SetValue(self.mw.config.ReadInt('splashscreentime', 2500)/1000.0)
+        if __debug__:
+            self.dev_console.SetValue(self.mw.config.ReadInt('console', 0))
 
     def setdefaults(self):
         if self.commbox.GetValue()==self.setme:
@@ -704,6 +717,10 @@ class ConfigDialog(wx.Dialog):
         # SplashScreen Time
         self.mw.config.WriteInt('splashscreentime',
                                 int(self.splashscreen.GetValue()*1000))
+        # developer console
+        if __debug__:
+            self.mw.config.WriteInt('console',
+                                    self.dev_console.GetValue())
         # ensure config is saved
         self.mw.config.Flush()
         # update the status bar
@@ -1890,3 +1907,216 @@ class DRRecFileDialog(wx.Dialog):
         if _dlg.ShowModal()==wx.ID_OK:
             data_recording.set_start(_dlg.GetSelection())
         _dlg.Destroy()
+
+# About Dialog-----------------------------------------------------------------
+_license="""The BitPim code is under the GNU General Public License as detailed
+below.  Specific permission is granted for this code to be linked to
+OpenSSL (this is necessary because the OpenSSL license is not
+GPL-compatible).
+
+   In addition, as a special exception, the BitPim copyright holders
+   give permission to link the code of this program with the OpenSSL
+   library (or with modified versions of OpenSSL), and distribute
+   linked combinations including the two. You must obey the GNU
+   General Public License in all respects for all of the code used
+   other than OpenSSL. If you modify any files, you may extend this
+   exception to your version of the file, but you are not obligated to
+   do so. If you do not wish to do so, delete this exception statement
+   from your version.
+
+Please also note that some code is taken from other projects with a
+GPL compatible license.  This is noted in the specific files.
+
+BitPim also uses several other components with GPL compatible
+licenses.  The online help details those components, credits the
+authors and details the licenses.
+---------------------------------------------------------------------
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License version 2 as published by
+the Free Software Foundation.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.  Also see the BitPim Help for more details
+"""
+
+_copyright="""(C) 2003-2007 The code in BitPim is copyright by several people.  Please note the
+comments at the top of each file, as well as version control history.
+"""
+_description="""    BitPim is a program that allows you to view and manipulate data on many CDMA phones
+    from LG, Samsung, Sanyo and other manufacturers. This includes the PhoneBook,
+    Calendar, WallPapers, RingTones (functionality varies by phone) and the
+    Filesystem for most Qualcomm CDMA chipset based phones. To see when phones will
+    be supported, which ones are already supported and which features are supported,
+    see online help.
+"""
+def show_about_dlg(parent):
+    global _license, _copyright, _description
+    info = wx.AboutDialogInfo()
+    info.Name = "BitPim"
+    info.Version = version.versionstring+" - "+version.vendor
+    info.Copyright=_copyright
+    info.Description = _description
+    info.WebSite = ("http://www.bitpim.org", "www.bitpim.org")
+    info.Developers = [ "Roger Binns",
+                        "Joe Pham",
+                        "Stephen Wood",
+                        "Sean Burke",
+                        "Nathan Hjelm",
+                        "and others ..."]
+
+    info.License = _license
+    # Then we call wx.AboutBox giving it that info object
+    wx.AboutBox(info)
+
+# Generic Print Dialog----------------------------------------------------------
+class PrintDialog(wx.Dialog):
+    """A generic print dialog from which other can subclass for their own use"""
+    _template_filename=None
+    _style_filename=None
+
+    def __init__(self, widget, mainwindow, config, title):
+        super(PrintDialog, self).__init__(mainwindow, -1, title)
+        self._widget=widget
+        self._xcp=self._html=self._dns=None
+        self._tmp_file=common.gettempfilename("htm")
+        # main box sizer
+        vbs=wx.BoxSizer(wx.VERTICAL)
+        # create the main contents of the dialog
+        self._create_contents(vbs)
+        # create the separator & default buttons
+        self._create_buttons(vbs)
+        # all done
+        self.SetSizer(vbs)
+        self.SetAutoLayout(True)
+        vbs.Fit(self)
+
+    def _create_contents(self, vbs):
+        # subclass must implement
+        raise NotImplementedError
+
+    def _create_buttons(self, vbs):
+        vbs.Add(wx.StaticLine(self, -1), 0, wx.EXPAND|wx.TOP|wx.BOTTOM, 5)
+        hbs=wx.BoxSizer(wx.HORIZONTAL)
+        for b in ((None, wx.ID_PRINT, self.OnPrint),
+                  ('Page Setup', wx.ID_PAGE_SETUP, self.OnPageSetup),
+                  (None, wx.ID_PREVIEW, self.OnPrintPreview),
+                  ('Save as HTML', -1, self.OnSaveHTML),
+                  (None, wx.ID_CLOSE, self.OnClose)):
+            if b[0]:
+                btn=wx.Button(self, b[1], b[0])
+            else:
+                btn=wx.Button(self, b[1])
+            hbs.Add(btn, 0, wx.ALIGN_CENTER|wx.ALL, 5)
+            if b[2] is not None:
+                wx.EVT_BUTTON(self, btn.GetId(), b[2])
+        vbs.Add(hbs, 0, wx.ALIGN_CENTRE|wx.EXPAND|wx.ALL, 5)
+
+    def _init_print_data(self):
+        # Initialize the dns dict with empty data
+        pass
+    def _get_print_data(self):
+        raise NotImplementedError
+
+    def _gen_print_data(self):
+        # generate the html page of the print data
+        if self._xcp is None:
+            # build the whole document template
+            self._xcp=xyaptu.xcopier(None)
+            tmpl=file(guihelper.getresourcefile(self._template_filename),
+                      'rt').read()
+            self._xcp.setupxcopy(tmpl)
+        if self._dns is None:
+            self._dns={ 'common': __import__('common') }
+            self._dns['guihelper']=__import__('guihelper')
+            self._init_print_data()
+        self._get_print_data()
+        self._html=self._xcp.xcopywithdns(self._dns.copy())
+        # apply styles
+        sd={'styles': {}, '__builtins__': __builtins__ }
+        try:
+            if self._style_filename:
+                execfile(guihelper.getresourcefile(self._style_filename),
+                         sd, sd)
+        except UnicodeError:
+            common.unicode_execfile(guihelper.getresourcefile(self._style_filename),
+                                    sd, sd)
+        try:
+            self._html=bphtml.applyhtmlstyles(self._html, sd['styles'])
+        except:
+            if __debug__:
+                file('debug.html', 'wt').write(self._html)
+            raise
+
+    # standard handlers
+    def OnPrint(self, _):
+        self._gen_print_data()
+        wx.GetApp().htmlprinter.PrintText(self._html)
+    def OnPageSetup(self, _):
+        wx.GetApp().htmlprinter.PageSetup()
+    def OnPrintPreview(self, _):
+        self._gen_print_data()
+        wx.GetApp().htmlprinter.PreviewText(self._html)
+    def OnSaveHTML(self, _):
+        _dlg=wx.FileDialog(self, wildcard="Web Page (*.htm;*.html)|*.htm;*html",
+                           style=wx.FD_SAVE|wx.FD_OVERWRITE_PROMPT)
+        if _dlg.ShowModal()==wx.ID_OK:
+            self._gen_print_data()
+            file(_dlg.GetPath(), 'wt').write(self._html)
+        _dlg.Destroy()
+    def OnClose(self, _):
+        try:
+            # remove the temp file, ignore exception if file does not exist
+            os.remove(self._tmp_file)
+        except:
+            pass
+        self.EndModal(wx.ID_CANCEL)
+
+# SMS Print Dialog--------------------------------------------------------------
+class SMSPrintDialog(PrintDialog):
+
+    _template_filename='sms.xy'
+    _title='SMS Print'
+    _item_name='SMS Messages'
+
+    def __init__(self, smswidget, mainwindow, config):
+        self._sel_data=smswidget.get_selected_data()
+        self._data=smswidget.get_data()
+        super(SMSPrintDialog, self).__init__(smswidget, mainwindow,
+                                             config, self._title)
+
+    def _create_contents(self, vbs):
+        rbs=wx.StaticBoxSizer(wx.StaticBox(self, -1, self._item_name), wx.VERTICAL)
+        lsel=len(self._sel_data)
+        lall=len(self._data)
+        self.rows_selected=wx.RadioButton(self, wx.NewId(), "Selected (%d)" % (lsel,), style=wx.RB_GROUP)
+        self.rows_all=wx.RadioButton(self, wx.NewId(), "All (%d)" % (lall,))
+        if lsel==0:
+            self.rows_selected.Enable(False)
+            self.rows_selected.SetValue(0)
+            self.rows_all.SetValue(1)
+        rbs.Add(self.rows_selected, 0, wx.EXPAND|wx.ALL, 2)
+        rbs.Add(self.rows_all, 0, wx.EXPAND|wx.ALL, 2)
+        vbs.Add(rbs, 0, wx.EXPAND|wx.ALL, 5)
+
+    def _init_print_data(self):
+        # Initialize the dns dict with empty data
+        self._dns['items']={}
+        self._dns['keys']=[]
+
+    def _get_print_data(self):
+        if self.rows_all.GetValue():
+            _items=self._data
+        else:
+            _items=self._sel_data
+        _keys=_items.keys()
+        _keys.sort()
+        self._dns['items']=_items
+        self._dns['keys']=_keys
+
+# Memo Print Dialog-------------------------------------------------------------
+class MemoPrintDialog(SMSPrintDialog):
+    _template_filename='memo.xy'
+    _title='Memo Print'
+    _item_name='Memo Entries'
