@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: ical_calendar.py 3624 2006-10-20 21:46:22Z djpham $
+### $Id: ical_calendar.py 4160 2007-03-22 22:07:51Z djpham $
 
 "Deals with iCalendar calendar import stuff"
 
@@ -90,6 +90,15 @@ class iCalendarImportData(parentclass):
                 raise
             return False
 
+    def _conv_valarm(self, v, dd):
+        # convert a VALARM block to alarm value, if available/applicable
+        if v.get('value', None)!='VALARM':
+            return False
+        _trigger=v.get('params', {}).get('TRIGGER', None)
+        if _trigger:
+            return self._conv_alarm(_trigger, dd)
+        return False
+        
     def _conv_duration(self, v, dd):
         # compute the 'end' date based on the duration
         return (datetime.datetime(*dd['start'])+\
@@ -238,9 +247,9 @@ class iCalendarImportData(parentclass):
         ('LOCATION', 'location', parentclass._conv_str),
         ('PRIORITY', 'priority', parentclass._conv_priority),
         ('SUMMARY', 'description', parentclass._conv_str),
-        ('TRIGGER', 'alarm', _conv_alarm),
         ('RRULE', 'repeat', _conv_repeat),
         ('EXDATE', 'exceptions', _conv_exceptions),
+        ('BEGIN-END', 'alarm', _conv_valarm),
         ]
 
 #-------------------------------------------------------------------------------
@@ -279,7 +288,7 @@ class ExportDialog(ExportDialogParent):
         f.write(out_line('BEGIN', None, 'STANDARD', None))
         f.write(out_line('DTSTART', None, '20051030T020000', None))
         f.write(out_line('RRULE', None,
-                         'FREQ=YEARLY;INTERVAL=1;BYDAY=-1SU;BYMONTH=10', None))
+                         'FREQ=YEARLY;INTERVAL=1;BYDAY=1SU;BYMONTH=11', None))
         f.write(out_line('TZOFFSETFROM', None,
                          '%05d'%_offset_daylight, None))
         f.write(out_line('TZOFFSETTO', None,
@@ -289,7 +298,7 @@ class ExportDialog(ExportDialogParent):
         f.write(out_line('BEGIN', None, 'DAYLIGHT', None))
         f.write(out_line('DTSTART', None, '20060402T020000', None))
         f.write(out_line('RRULE', None,
-                         'FREQ=YEARLY;INTERVAL=1;BYDAY=1SU;BYMONTH=4', None))
+                         'FREQ=YEARLY;INTERVAL=1;BYDAY=2SU;BYMONTH=3', None))
         f.write(out_line('TZOFFSETFROM', None,
                          '%05d'%_offset_standard, None))
         f.write(out_line('TZOFFSETTO', None,
