@@ -7,13 +7,15 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: imp_cal_preset.py 3727 2006-12-05 03:52:02Z djpham $
+### $Id: imp_cal_preset.py 4195 2007-04-10 22:52:15Z djpham $
 
 """ Handle Import Calendar Preset feature
 """
 
 # System
+import calendar
 import copy
+import datetime
 import random
 import sha
 
@@ -24,6 +26,7 @@ import wx.wizard as wiz
 # BitPim
 import common_calendar
 import database
+import guihelper
 import imp_cal_wizard
 import importexport
 import setphone_wizard
@@ -32,6 +35,7 @@ import setphone_wizard
 IMP_OPTION_REPLACEALL=0
 IMP_OPTION_ADD=1
 IMP_OPTION_PREVIEW=2
+IMP_OPTION_MERGE=3
 
 #-------------------------------------------------------------------------------
 class ImportCalendarDataObject(common_calendar.FilterDataObject):
@@ -170,7 +174,7 @@ class PresetFilterPage(setphone_wizard.MyPage):
         self._display('start', '_start', _fmt)
         self._display('end', '_end', _fmt)
         self._display('preset_date', '_preset',
-                      "['This Week', 'This Month', 'This Year'][_v]")
+                      "['This Week', 'This Month', 'This Year', 'Next 7 Days'][_v]")
         self._display('rpt_events', '_repeat',
                       "{ True: 'Import as mutil-single events', False: ''}[_v]")
         if self._data.get('no_alarm', None):
@@ -192,7 +196,7 @@ class PresetFilterPage(setphone_wizard.MyPage):
 
 #-------------------------------------------------------------------------------
 class ImportOptionPage(imp_cal_wizard.ImportOptionPage):
-    _choices=('Replace All', 'Add', 'Preview')
+    _choices=('Replace All', 'Add', 'Preview', 'Merge')
 
 #-------------------------------------------------------------------------------
 class ImportCalendarPresetWizard(wiz.Wizard):
@@ -244,6 +248,7 @@ class ImportCalendarPresetWizard(wiz.Wizard):
 class CalendarPreviewDialog(wx.Dialog):
     ID_ADD=wx.NewId()
     ID_REPLACE=wx.NewId()
+    ID_MERGE=wx.NewId()
     def __init__(self, parent, data):
         super(CalendarPreviewDialog, self).__init__(parent, -1,
                                                     'Calendar Import Preview')
@@ -260,6 +265,9 @@ class CalendarPreviewDialog(wx.Dialog):
         _btn=wx.Button(self, self.ID_ADD, 'Add')
         wx.EVT_BUTTON(self, self.ID_ADD, self._OnButton)
         _hbs.Add(_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
+        _btn=wx.Button(self, self.ID_MERGE, 'Merge')
+        wx.EVT_BUTTON(self, self.ID_MERGE, self._OnButton)
+        _hbs.Add(_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         _hbs.Add(wx.Button(self, wx.ID_CANCEL, 'Cancel'), 0,
                  wx.ALIGN_CENTRE|wx.ALL, 5)
         _vbs.Add(_hbs, 0, wx.EXPAND|wx.ALL, 5)
@@ -273,6 +281,7 @@ class CalendarPreviewDialog(wx.Dialog):
 #-------------------------------------------------------------------------------
 class ImportCalendarPresetDialog(wx.Dialog):
     ID_ADD=wx.NewId()
+    ID_MERGE=wx.NewId()
 
     def __init__(self, parent, id, title):
         self._parent=parent
@@ -280,7 +289,8 @@ class ImportCalendarPresetDialog(wx.Dialog):
         self._import_data=None
         self._buttons=[]
         super(ImportCalendarPresetDialog, self).__init__(parent, id,
-                                                         title)
+                                                         title,
+                                                         size=(500, 500))
         _vbs=wx.BoxSizer(wx.VERTICAL)
         _static_bs=wx.StaticBoxSizer(wx.StaticBox(self, -1,
                                                   'Available Presets:'),
@@ -295,23 +305,24 @@ class ImportCalendarPresetDialog(wx.Dialog):
         wx.EVT_BUTTON(self, _btn.GetId(), self._OnRun)
         self._buttons.append(_btn)
         _hbs.Add(_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
-        _btn=wx.Button(self, -1, 'New')
+        _btn=wx.Button(self, wx.ID_NEW)
         wx.EVT_BUTTON(self, _btn.GetId(), self._OnNew)
         _hbs.Add(_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         _btn=wx.Button(self, -1, 'Edit')
         wx.EVT_BUTTON(self, _btn.GetId(), self._OnEdit)
         self._buttons.append(_btn)
         _hbs.Add(_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
-        _btn=wx.Button(self, -1, 'Delete')
+        _btn=wx.Button(self, wx.ID_DELETE)
         self._buttons.append(_btn)
         wx.EVT_BUTTON(self, _btn.GetId(), self._OnDel)
         _hbs.Add(_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
-        _hbs.Add(wx.Button(self, wx.ID_CANCEL, 'Cancel'),
+        _hbs.Add(wx.Button(self, wx.ID_CANCEL),
                  0, wx.ALIGN_CENTRE|wx.ALL, 5)
         _vbs.Add(_hbs, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
-        self.SetSizer(_vbs)
-        self.SetAutoLayout(True)
-        _vbs.Fit(self)
+        self.SetSizerAndFit(_vbs)
+        if guihelper.IsGtk():
+            # On Linux, without this, the dialog clips the buttons
+            self.SetSizeHints(-1, 175)
         self._get_from_fs()
         self._populate()
 
@@ -330,8 +341,50 @@ class ImportCalendarPresetDialog(wx.Dialog):
             return wx.ID_OK
         elif _ret_code==CalendarPreviewDialog.ID_ADD:
             return self.ID_ADD
+        elif _ret_code==CalendarPreviewDialog.ID_MERGE:
+            return self.ID_MERGE
         return wx.ID_CANCEL
 
+    def _get_preset_thisweek(self):
+        # return the dates of (today, Sat)
+        _today=datetime.date.today()
+        _dow=_today.isoweekday()%7  #Sun=0, Sat=6
+        _end=_today+datetime.timedelta(6-_dow)
+        return ((_today.year, _today.month, _today.day),
+                (_end.year, _end.month, _end.day))
+
+    def _get_preset_thismonth(self):
+        # return the dates of (today, end-of-month)
+        _today=datetime.date.today()
+        _end=_today.replace(day=calendar.monthrange(_today.year,_today.month)[1])
+        return ((_today.year, _today.month, _today.day),
+                (_end.year, _end.month, _end.day))
+
+    def _get_preset_thisyear(self):
+        # return the dates of (today, end-of-year)
+        _today=datetime.date.today()
+        _end=_today.replace(month=12, day=31)
+        return ((_today.year, _today.month, _today.day),
+                (_end.year, _end.month, _end.day))
+
+    def _get_preset_next7(self):
+        # return the dates of (today, today+6)
+        _today=datetime.date.today()
+        _end=_today+datetime.timedelta(days=6)
+        return ((_today.year, _today.month, _today.day),
+                (_end.year, _end.month, _end.day))
+
+    def _adjust_filter_dates(self, entry):
+        # Adjust the start/end dates of the filter
+        _preset_date=entry.get('preset_date', None)
+        if _preset_date is None:
+            # No Preset date, bail
+            return
+        entry['start'], entry['end']=getattr(self,
+                                             ['_get_preset_thisweek',
+                                              '_get_preset_thismonth',
+                                              '_get_preset_thisyear',
+                                              '_get_preset_next7'][_preset_date])()
     def _OnRun(self, _):
         _idx=self._name_lb.GetSelection()
         if _idx==wx.NOT_FOUND:
@@ -351,14 +404,18 @@ class ImportCalendarPresetDialog(wx.Dialog):
                                'Importing data, please wait ...',
                                parent=self)
         self._import_data.read(_source.get(), _dlg)
+        self._adjust_filter_dates(_entry)
         self._import_data.set_filter(_entry)
         _dlg.Destroy()
         wx.EndBusyCursor()
-        global IMP_OPTION_PREVIEW, IMP_OPTION_REPLACEALL, IMP_OPTION_ADD
-        if _entry['option']==IMP_OPTION_PREVIEW:
+        global IMP_OPTION_PREVIEW, IMP_OPTION_REPLACEALL, IMP_OPTION_ADD, IMP_OPTION_MERGE
+        _option=_entry.get('option', IMP_OPTION_PREVIEW)
+        if _option==IMP_OPTION_PREVIEW:
             _ret_code=self._preview_data()
-        elif _entry['option']==IMP_OPTION_ADD:
+        elif _option==IMP_OPTION_ADD:
             _ret_code=self.ID_ADD
+        elif _option==IMP_OPTION_MERGE:
+            _ret_code=self.ID_MERGE
         else:
             _ret_code=wx.ID_OK
         self.EndModal(_ret_code)
