@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: memo.py 3324 2006-06-01 04:28:04Z djpham $
+### $Id: memo.py 4206 2007-04-27 20:19:34Z djpham $
 
 """
 Code to handle memo/note items
@@ -64,6 +64,7 @@ import phonebookentryeditor as pb_editor
 import pubsub
 import today
 import guihelper
+import guiwidgets
 import widgets
 
 widgets_list=[]
@@ -299,9 +300,9 @@ class MemoWidget(wx.Panel, widgets.BitPimWidget):
         self._memo_editor_w=self._w[2]
         # the bottom buttons
         hbs1=wx.BoxSizer(wx.HORIZONTAL)
-        self._save_btn=wx.Button(self, wx.NewId(), "Save")
-        self._revert_btn=wx.Button(self, wx.NewId(), "Revert")
-        help_btn=wx.Button(self, wx.ID_HELP, "Help")
+        self._save_btn=wx.Button(self, wx.ID_SAVE)
+        self._revert_btn=wx.Button(self, wx.ID_REVERT_TO_SAVED)
+        help_btn=wx.Button(self, wx.ID_HELP)
         hbs1.Add(self._save_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs1.Add(help_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs1.Add(self._revert_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
@@ -463,6 +464,18 @@ class MemoWidget(wx.Panel, widgets.BitPimWidget):
         dict['memo']=copy.deepcopy(self._data)
         return dict
 
+    def get_selected_data(self):
+        # return a dict of selected items
+        res={}
+        for _idx in self._item_list.GetSelections():
+            _key=self._item_list.GetClientData(_idx)
+            if _key:
+                res[_key]=self._data[_key]
+        return res
+
+    def get_data(self):
+        return self._data
+
     def populate(self, dict):
         self._data=dict.get('memo', {})
         self._populate()
@@ -516,8 +529,18 @@ class MemoWidget(wx.Panel, widgets.BitPimWidget):
 
     def _OnRevert(self, evt):
         self.ignoredirty=True
+        # Enable the list to get the selection
+        self._item_list.Enable()
         sel_idx=self._item_list.GetSelection()
-        k=self._item_list.GetClientData(sel_idx)
-        self._populate_each(k)
+        if sel_idx!=wx.NOT_FOUND:
+            k=self._item_list.GetClientData(sel_idx)
+            self._populate_each(k)
         self.ignoredirty=False
         self.setdirty(False)
+
+    def OnPrintDialog(self, mainwindow, config):
+        dlg=guiwidgets.MemoPrintDialog(self, mainwindow, config)
+        dlg.ShowModal()
+        dlg.Destroy()
+    def CanPrint(self):
+        return True
