@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: outlook_calendar.py 3677 2006-11-14 03:26:11Z djpham $
+### $Id: outlook_calendar.py 4179 2007-04-03 01:07:57Z djpham $
 
 "Deals with Outlook calendar import stuff"
 
@@ -273,6 +273,10 @@ class OutlookCalendarImportData:
             rp.interval=r_interval
             rp.interval2=r_interval2
             rp.dow=r_dow
+        # check for invalid monthly type
+        if rp.repeat_type==rp.monthly and \
+           rp.dow in (rp.dow_weekday, rp.dow_weekend):
+            rp.dow=0
         # add the list of exceptions
         for k in e.get('exceptions', []):
             rp.add_suppressed(*k[:3])
@@ -493,7 +497,7 @@ class OutlookImportCalDialog(common_calendar.PreviewDialog):
         ('alarm', 'Alarm', 80, common_calendar.bp_alarm_str),
         ('categories', 'Category', 150, common_calendar.category_str)
         ]
-    ID_ADD=wx.NewId()
+
     _config_name='import/calendar/outlookdialog'
     _browse_label='Outlook Calendar Folder:'
     _progress_dlg_title='Outlook Calendar Import'
@@ -532,6 +536,7 @@ class OutlookImportCalDialog(common_calendar.PreviewDialog):
         hbs.Add(wx.Button(self, id_import, 'Import'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs.Add(wx.Button(self, wx.ID_OK, 'Replace All'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs.Add(wx.Button(self, self.ID_ADD, 'Add'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
+        hbs.Add(wx.Button(self, self.ID_MERGE, 'Merge'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs.Add(wx.Button(self, wx.ID_CANCEL, 'Cancel'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         id_filter=wx.NewId()
         hbs.Add(wx.Button(self, id_filter, 'Filter'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
@@ -539,7 +544,8 @@ class OutlookImportCalDialog(common_calendar.PreviewDialog):
         main_bs.Add(hbs, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         wx.EVT_BUTTON(self, id_import, self.OnImport)
         wx.EVT_BUTTON(self, id_filter, self.OnFilter)
-        wx.EVT_BUTTON(self, self.ID_ADD, self.OnAdd)
+        wx.EVT_BUTTON(self, self.ID_ADD, self.OnEndModal)
+        wx.EVT_BUTTON(self, self.ID_MERGE, self.OnEndModal)
         wx.EVT_BUTTON(self, wx.ID_HELP, lambda *_: wx.GetApp().displayhelpid(helpids.ID_DLG_CALENDAR_IMPORT))
 
     def OnImport(self, evt):
@@ -570,13 +576,12 @@ class OutlookImportCalDialog(common_calendar.PreviewDialog):
     def OnFilter(self, evt):
         cat_list=self._oc.get_category_list()
         dlg=self._filter_dlg_class(self, -1, 'Filtering Parameters', cat_list)
-##        dlg.set(self._oc.get_filter())
         if dlg.ShowModal()==wx.ID_OK:
             self._oc.set_filter(dlg.get())
             self.populate(self._oc.get_display_data())
 
-    def OnAdd(self, evt):
-        self.EndModal(self.ID_ADD)
+    def OnEndModal(self, evt):
+        self.EndModal(evt.GetId())
 
     def get(self):
         return self._oc.get()
