@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: package.py 3771 2006-12-11 04:44:56Z djpham $
+### $Id: package.py 4287 2007-06-12 02:33:21Z djpham $
 
 # This file provides the packaging definitions used by the buildrelease system
 
@@ -24,7 +24,7 @@ def sanitycheck():
     print "=== Sanity check ==="
 
     print "svn location",
-    if not "$HeadURL: https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/0.9.10/src/package.py $".split(":",1)[1].strip().startswith("https://bitpim.svn.sourceforge.net"):
+    if not "$HeadURL: https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/1.0.0/src/package.py $".split(":",1)[1].strip().startswith("https://bitpim.svn.sourceforge.net"):
         raise Exception("Needs to be checked out from https://bitpim.svn.sourceforge.net")
     print "  OK"
 
@@ -35,7 +35,7 @@ def sanitycheck():
 
     print "wxPython version",
     import wx
-    if wx.VERSION[:4]!=(2,6,3,3):
+    if wx.VERSION[:4]!=(2,8,4,0):
         raise Exception("Should be wxPython 2.6.3.3.  This is "+`wx.VERSION`)
     print "  OK"
 
@@ -57,7 +57,7 @@ def sanitycheck():
     print "  OK"
 
     print "paramiko version",
-    expect='1.4 (oddish)'
+    expect='1.7 (zubat)'
     import paramiko
     if paramiko.__version__!=expect:
         raise Exception("Should be %s version of paramiko - you have %s" % (expect, paramiko.__version__))
@@ -73,13 +73,13 @@ def sanitycheck():
 
     print "apsw",
     import apsw
-    ver="3.3.5-r1"
+    ver="3.3.13-r1"
     if apsw.apswversion()!=ver:
         raise Exception("Should be apsw version %s - you have %s" % (ver, apsw.apswversion()))
     print "  OK"
 
     print "sqlite",
-    ver="3.3.5"
+    ver="3.3.17"
     if apsw.sqlitelibversion()!=ver:
         raise Exception("Should be sqlite version %s - you have %s" % (ver, apsw.sqlitelibversion()))
     print "  OK"
@@ -149,8 +149,13 @@ def isofficialbuild():
     import socket
     h=socket.gethostname().lower()
     # not built by rogerb (or stevep/n9yty) are unofficial
-    return h in ('rh9bitpim.rogerbinns.com', "roger-sqyvr14d3",
-             "smpbook.n9yty.com", "smpbook.local.", "rogerbmac.rogerbinns.com", "rogerbmac.local")
+    return h in ('rh9bitpim.rogerbinns.com', "roger-ba470eb54",
+                 "rogerbmac.rogerbinns.com",
+                 # Joe's build machines
+                 "tinyone", "tiny2one",
+                 # Sean's
+                 "leviathan.local",
+                 )
 
 def ensureofficial():
     """If this is not an official build then ensure that version.vendor doesn't say it is"""
@@ -158,18 +163,24 @@ def ensureofficial():
     version.__freeze()
     print "Reloading version"
     reload(version)
-    if not isofficialbuild():
-        if version.vendor=="official":
-            # so modify file
-            versionpy=os.path.join(os.path.dirname(__file__), "version.py")
-            out=[]
-            for line in open(versionpy, "rt"):
-                if line.startswith('vendor="'):
-                    line='vendor="$%s %s $"\n' % ("Id:", "unofficial")
-                out.append(line)
-                    
-            open(versionpy, "wt").write("".join(out))
-            reload(version)
+    officialbuild=isofficialbuild()
+    if officialbuild and version.vendor=='unofficial':
+        vendor='official'
+    elif not officialbuild and version.vendor=='official':
+        vendor='unofficial'
+    else:
+        vendor=None
+    if vendor:
+        # so modify file
+        versionpy=os.path.join(os.path.dirname(__file__), "version.py")
+        out=[]
+        for line in open(versionpy, "rt"):
+            if line.startswith('vendor="'):
+                line='vendor="$%s %s $"\n' % ("Id:", vendor)
+            out.append(line)
+                
+        open(versionpy, "wt").write("".join(out))
+        reload(version)
 
 def getversion():
     return version.version
@@ -225,12 +236,32 @@ def getpy2exeoptions(defaults):
     defaults['options']['py2exe']['compressed']=0 # make setup.exe smaller but installed code larger
     return defaults
 
+udevrules_filename='60-bitpim.rules'
+udevrules_line='ACTION=="add", SYSFS{idProduct}=="%04x", SYSFS{idVendor}=="%04x", RUN+="/usr/bin/bpudev $env{DEVNAME} $number $sysfs{devnum}"'
+from common import importas
+def generate_udevrules():
+    """Generate the udev rules file based on all the known VIDs and PIDs"""
+    global udevrules_filename, udevrules_line
+    _ids={}
+    for _f in phones.getallmodulenames():
+        _profile=importas(_f)
+        if hasattr(_profile.Profile, 'usbids'):
+            for _id in _profile.Profile.usbids:
+                _ids[_id]=True
+    _rules=[]
+    for _entry in _ids:
+        _rules.append(udevrules_line%(_entry[1], _entry[0]))
+    _f=file('resources/%s'%udevrules_filename, 'wt').write('\n'.join(_rules))
+    
 def copyresources(destdir):
+    if sys.platform=='linux2':
+        generate_udevrules()
     import packageutils
     packageutils.copysvndir('resources', os.path.join(destdir, 'resources'), resourcefilter)
     packageutils.copysvndir('helpers', os.path.join(destdir, 'helpers'), resourcefilter)
 
 def resourcefilter(srcfilename, destfilename):
+    global udevrules_filename
     exts=[ '.xy', '.png', '.ttf', '.wav', '.jpg', '.css', '.pdc', '.ids', '.ico']
     files=[]
     if sys.platform=='win32':
@@ -238,7 +269,7 @@ def resourcefilter(srcfilename, destfilename):
         exts=exts+['.chm', '.exe', '.dll']
     if sys.platform=='linux2':
         exts=exts+['.lbin', '.htb']
-        files.append('usbcell')
+        files+=['bpudev', udevrules_filename]
     if sys.platform=='darwin':
         exts=exts+['.mbin', '.htb']
     if os.path.splitext(srcfilename)[1] in exts or \
