@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: phonebookentryeditor.py 3647 2006-11-08 03:39:16Z djpham $
+### $Id: phonebookentryeditor.py 4287 2007-06-12 02:33:21Z djpham $
 
 import wx
 
@@ -84,6 +84,33 @@ class DirtyUIBase(wx.Panel):
         super(DirtyUIBase, self).Enable(enable)
         self.Refresh()
 
+# My ListBox class--------------------------------------------------------------
+class ListBox(wx.ListBox):
+    """BitPim ListBox class that caches the selection string necessary for this
+    implementation.
+    """
+    def __init__(self, *args, **kwargs):
+        super(ListBox, self).__init__(*args,  **kwargs)
+        self._selstr=''
+        wx.EVT_LISTBOX(self, self.GetId(), self._OnSelected)
+    def _OnSelected(self, evt):
+        self._selstr=evt.GetString()
+        evt.Skip()
+    def GetStringSelection(self):
+        return self._selstr
+    def SetStringSelection(self, selection):
+        try:
+            super(ListBox, self).SetStringSelection(selection)
+            self._selstr=selection
+        except:
+            self._selstr=''
+    def SetSelection(self, idx):
+        try:
+            super(ListBox, self).SetSelection(idx)
+            self._selstr=self.GetString(idx)
+        except:
+            self._selstr=''
+
 # RingtoneEditor----------------------------------------------------------------
 class RingtoneEditor(DirtyUIBase):
     "Edit a ringtone"
@@ -120,7 +147,7 @@ class RingtoneEditor(DirtyUIBase):
 
         hs.Add(vs, 1, wx.EXPAND|wx.ALL, 5)
 
-        self.ringtone=wx.ListBox(self, self.ID_LIST, choices=[self.unnamed], size=(-1,200))
+        self.ringtone=ListBox(self, self.ID_LIST, choices=[self.unnamed], size=(-1,200))
         hs.Add(self.ringtone, 1, wx.EXPAND|wx.ALL, 5)
         if navtoolbar:
             hs.Add(NavToolBar(self, False), 0, wx.EXPAND|wx.BOTTOM, 5)
@@ -138,31 +165,33 @@ class RingtoneEditor(DirtyUIBase):
         super(RingtoneEditor, self).__del__()
 
     def OnRingtoneUpdates(self, msg):
-        "Receives pubsub message with ringtone list"
+        # wxPython/wxWidget bug: ListBox.Clear emits a wx.EVT_LISTBOX event
+        # it shouldn't
+        self.Ignore()
         tones=msg.data[:]
-        cur=self.Get()
+        cur=self._get()
         self.ringtone.Clear()
         self.ringtone.Append(self.unnamed)
         for p in tones:
             self.ringtone.Append(p)
-        self.Set(cur)
+        self._set(cur)
+        self.Clean()
 
     def OnLBClicked(self, evt=None):
+        if self.ringtone.GetSelection()==wx.NOT_FOUND:
+            return
         self.OnDirtyUI(evt)
         self._updaterequested=False
-        v=self.Get().get('ringtone', None)
+        v=self._get().get('ringtone', None)
         self.SetPreview(v)
 
     def SetPreview(self, name):
         if name is None:
             self.preview.SetPage('')
         else:
-            pass
             self.preview.SetPage('<img src="bpimage:ringer.png;width=24;height=24"><br>At some point there will be info about the ringtone as well as the ability to play it here')
-            pass
 
-    def Set(self, data):
-        self.Ignore(True)
+    def _set(self, data):
         if data is None:
             wp=self.unnamed
             type='call'
@@ -181,13 +210,11 @@ class RingtoneEditor(DirtyUIBase):
         # zero len?
         if len(wp)==0:
             self.ringtone.SetSelection(0)
-            self.Clean()
             return
 
         # try using straight forward name
         try:
             self.ringtone.SetStringSelection(wp)
-            self.Clean()
             return
         except:
             pass
@@ -195,7 +222,6 @@ class RingtoneEditor(DirtyUIBase):
         # ok, with unknownselprefix
         try:
             self.ringtone.SetStringSelection(self.unknownselprefix+wp)
-            self.Clean()
             return
         except:
             pass
@@ -203,10 +229,13 @@ class RingtoneEditor(DirtyUIBase):
         # ok, just add it
         self.ringtone.InsertItems([self.unknownselprefix+wp], 1)
         self.ringtone.SetStringSelection(self.unknownselprefix+wp)
+
+    def Set(self, data):
+        self.Ignore(True)
+        self._set(data)
         self.Clean()
 
-    def Get(self):
-        self.Clean()
+    def _get(self):
         res={}
         rt=self.ringtone.GetStringSelection()
         if rt==self.unnamed:
@@ -218,6 +247,10 @@ class RingtoneEditor(DirtyUIBase):
             res['use']=self.type.GetStringSelection()
         return res
         
+    def Get(self):
+        self.Clean()
+        return self._get()
+        
 # WallpaperEditor---------------------------------------------------------------
 class WallpaperEditor(DirtyUIBase):
 
@@ -252,7 +285,7 @@ class WallpaperEditor(DirtyUIBase):
 
         hs.Add(vs, 1, wx.EXPAND|wx.ALL, 5)
 
-        self.wallpaper=wx.ListBox(self, self.ID_LIST, choices=[self.unnamed], size=(-1,200), style=wx.LB_SINGLE)
+        self.wallpaper=ListBox(self, self.ID_LIST, choices=[self.unnamed], size=(-1,200), style=wx.LB_SINGLE)
         hs.Add(self.wallpaper, 1, wx.EXPAND|wx.ALL, 5)
         if navtoolbar:
             hs.Add(NavToolBar(self, False), 0, wx.EXPAND|wx.BOTTOM, 5)
@@ -271,15 +304,21 @@ class WallpaperEditor(DirtyUIBase):
 
     def OnWallpaperUpdates(self, msg):
         "Receives pubsub message with wallpaper list"
+        # wxPython/wxWidget bug: ListBox.Clear emits a wx.EVT_LISTBOX event
+        # it shouldn't
+        self.Ignore()
         papers=msg.data[:]
-        cur=self.Get()
+        cur=self._get()
         self.wallpaper.Clear()
         self.wallpaper.Append(self.unnamed)
         for p in papers:
             self.wallpaper.Append(p)
-        self.Set(cur)
+        self._set(cur)
+        self.Clean()
 
     def OnLBClicked(self, evt=None):
+        if self.wallpaper.GetSelection()==wx.NOT_FOUND:
+            return
         self.OnDirtyUI(evt)
         v=self.Get().get('wallpaper', None)
         self.SetPreview(v)
@@ -290,8 +329,7 @@ class WallpaperEditor(DirtyUIBase):
         else:
             self.preview.SetImage(name)        
 
-    def Set(self, data):
-        self.Ignore()
+    def _set(self, data):
         if data is None:
             wp=self.unnamed
             type='call'
@@ -309,13 +347,11 @@ class WallpaperEditor(DirtyUIBase):
 
         if len(wp)==0:
             self.wallpaper.SetSelection(0)
-            self.Clean()
             return
 
         # try using straight forward name
         try:
             self.wallpaper.SetStringSelection(wp)
-            self.Clean()
             return
         except:
             pass
@@ -323,7 +359,6 @@ class WallpaperEditor(DirtyUIBase):
         # ok, with unknownselprefix
         try:
             self.wallpaper.SetStringSelection(self.unknownselprefix+wp)
-            self.Clean()
             return
         except:
             pass
@@ -331,10 +366,13 @@ class WallpaperEditor(DirtyUIBase):
         # ok, just add it
         self.wallpaper.InsertItems([self.unknownselprefix+wp], 1)
         self.wallpaper.SetStringSelection(self.unknownselprefix+wp)
+
+    def Set(self, data):
+        self.Ignore()
+        self._set(data)
         self.Clean()
 
-    def Get(self):
-        self.Clean()
+    def _get(self):
         res={}
         wp=self.wallpaper.GetStringSelection()
         if wp==self.unnamed:
@@ -346,6 +384,10 @@ class WallpaperEditor(DirtyUIBase):
             res['use']=self.type.GetStringSelection()
         return res
 
+    def Get(self):
+        self.Clean()
+        return self._get()
+
 # CategoryManager---------------------------------------------------------------
 class CategoryManager(wx.Dialog):
 
@@ -1150,15 +1192,13 @@ class NameEditor(DirtyUIBase):
                 res[name]=widget.GetValue()
         return res
 
-# StorageEditor-----------------------------------------------------------------
-class StorageEditor(DirtyUIBase):
+# MiscEditor-----------------------------------------------------------------
+class MiscEditor(DirtyUIBase):
     def __init__(self, parent, _, navtoolbar=False):
-        super(StorageEditor, self).__init__(parent)
-        vs=wx.StaticBoxSizer(field_color.build_color_field(self,
-                                                           wx.StaticBox,
-                                                           (self, -1, "Storage Details"),
-                                                           'storage'),
+        super(MiscEditor, self).__init__(parent)
+        vs=wx.StaticBoxSizer(wx.StaticBox(self, -1, "Misc Details"),
                              wx.VERTICAL)
+        # storage field
         hs=wx.BoxSizer(wx.HORIZONTAL)
         hs.Add(field_color.build_color_field(self, wx.StaticText,
                                              (self, -1, "Storage Option:"),
@@ -1166,25 +1206,32 @@ class StorageEditor(DirtyUIBase):
                0, wx.ALIGN_CENTRE|wx.ALL, 5)
         self._storage=wx.ComboBox(self, -1, 'Phone', choices=["Phone", "SIM"],
                                   style=wx.CB_READONLY)
+        wx.EVT_COMBOBOX(self, self._storage.GetId(), self.OnDirtyUI)
         hs.Add(self._storage, 0, wx.EXPAND|wx.LEFT, 5)
         vs.Add(hs, 0, wx.EXPAND|wx.ALL, 5)
+        # secret field
+        self._secret=field_color.build_color_field(self, wx.CheckBox,
+                                                   (self, -1,
+                                                    'This entry is private/secret'),
+                                                   'secret')
+
+        wx.EVT_CHECKBOX(self, self._secret.GetId(), self.OnDirtyUI)
+        vs.Add(self._secret, 0, wx.EXPAND|wx.ALL, 5)
+        # all done
         self.SetSizer(vs)
         vs.Fit(self)
 
     def Set(self, data):
-        _value=False
-        for d in data.get('flags', []):
-            if d.has_key('sim'):
-                _value=d['sim']
-                break
-        if _value:
-            _choice='SIM'
-        else:
-            _choice='Phone'
-        self._storage.SetValue(_choice)
+        self._storage.SetValue(data.get('sim', False) and 'SIM' or 'Phone')
+        self._secret.SetValue(data.get('secret', False))
 
     def Get(self):
-        return { 'flags': [{'sim': self._storage.GetValue()=='SIM' }]}
+        _res={}
+        if self._storage.GetValue()=='SIM':
+            _res['sim']=True
+        if self._secret.GetValue():
+            _res['secret']=True
+        return _res
 
 # EditorManager-----------------------------------------------------------------
 class EditorManager(fixedscrolledpanel.wxScrolledPanel):
@@ -1503,7 +1550,7 @@ class Editor(wx.Dialog):
         ("Categories", "categories", CategoryEditor),
         ("Wallpapers", "wallpapers", WallpaperEditor),
         ("Ringtones", "ringtones", RingtoneEditor),
-        ("Storage", None, StorageEditor),
+        ("Misc", 'flags', MiscEditor),
         ]
 
     def __init__(self, parent, data, title="Edit PhoneBook Entry",
@@ -1564,7 +1611,7 @@ class Editor(wx.Dialog):
         for name,key,klass in self.tabsfactory:
             widget=EditorManager(self.nb, klass)
             nb.AddPage(widget,name)
-            if key==keytoopenon:
+            if key==keytoopenon or keytoopenon in key:
                 nb.SetSelection(len(self.tabs))
             self.tabs.append(widget)
         # populate the data
