@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_brew.py 3725 2006-12-05 03:50:54Z djpham $
+### $Id: com_brew.py 4287 2007-06-12 02:33:21Z djpham $
 
 """Implements the "Brew" filesystem protocol"""
 
@@ -889,8 +889,6 @@ class RealBrewProtocol2:
             handle=self.openfile(name, p_brew.new_fileopen_mode_write, p_brew.new_fileopen_flag_existing)
         else:
             handle=self.openfile(name, p_brew.new_fileopen_mode_write, p_brew.new_fileopen_flag_create)
-        if not handle:
-            raise BrewNoSuchFileException
         try:
             remain=size
             pos=0
@@ -934,8 +932,6 @@ class RealBrewProtocol2:
         desc="Reading "+file
         data=cStringIO.StringIO()
         handle=self.openfile(file, p_brew.new_fileopen_mode_read)
-        if not handle:
-            raise BrewNoSuchFileException
         try:
             filesize=node['size']
             read=0
@@ -1007,10 +1003,13 @@ class RealBrewProtocol2:
                 if files and res.type==0: # file
                     results[direntry]={ 'name': direntry, 'type': 'file',
                                     'size': res.size }
-                    if res.date==0:
+                    try:
+                        if res.date<=0:
+                            results[direntry]['date']=(0, "")
+                        else:
+                            results[direntry]['date']=(res.date, time.strftime("%x %X", time.localtime(res.date)))
+                    except:
                         results[direntry]['date']=(0, "")
-                    else:
-                        results[direntry]['date']=(res.date, time.strftime("%x %X", time.localtime(res.date)))
                 elif directories and res.type: # directory
                     results[direntry]={ 'name': direntry, 'type': 'directory' }
                     if recurse>0:
@@ -1038,14 +1037,19 @@ class RealBrewProtocol2:
         res=self.sendbrewcommand(req, p_brew.new_statfileresponse)
         if res.flags==2:
             raise BrewNoSuchFileException
-        if res.type==1:
+        if res.type==1 or res.type==0x86:
+            # files on external media have type 0x86
             results={ 'name': name, 'type': 'file', 'size': res.size }
-            if res.created_date==0:
+        else:
+            results={ 'name': name, 'type': 'directory' }
+        try:
+            if res.created_date<=0:
                 results['date']=(0, '')
             else:
                 results['date']=(res.created_date, time.strftime("%x %X", time.localtime(res.created_date)))
-        else:
-            results={ 'name': name, 'type': 'directory' }
+        except:
+            # the date value got screwed up, just ignore it.
+            results['date']=(0, '')
         return results
 
 class BrewProtocol(RealBrewProtocol):
