@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lg.py 3530 2006-08-22 05:51:20Z djpham $
+### $Id: com_lg.py 4287 2007-06-12 02:33:21Z djpham $
 
 """Phonebook conversations with LG phones"""
 
@@ -104,6 +104,11 @@ class LGPhonebook:
         # turn it back to normal
         data=common.pppunescape(data)
 
+        if data[:2] != firsttwo:
+            # phonebook is busy
+            self.logdata("LG Phonebook busy response", data, None)
+            raise common.PhoneBookBusyException()
+
         # take off crc and terminator
         crc=data[-3:-1]
         data=data[:-3]
