@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgg4015.py 3037 2006-04-03 00:30:28Z rogerb $
+### $Id: com_lgg4015.py 3927 2007-01-22 03:15:22Z rogerb $
 
 """Communicate with the LG G4015 cell phone
 """
@@ -19,23 +19,25 @@ import time
 import bpcalendar
 import common
 import commport
-import com_gsm
+import com_etsi
 import guihelper
+import helpids
 import memo
 import nameparser
 import p_lgg4015
 import prototypes
 import sms
 
-class Phone(com_gsm.Phone):
+class Phone(com_etsi.Phone):
     """ Talk to the LG G4015 Phone"""
 
     desc='LG-G4015'
+    helpid=helpids.ID_PHONE_LGG4015
     protocolclass=p_lgg4015
     serialsname='lgg4015'
 
     def __init__(self, logtarget, commport):
-        com_gsm.Phone.__init__(self, logtarget, commport)
+        super(Phone,self).__init__(logtarget, commport)
         self.mode=self.MODENONE
 
     def getfundamentals(self, results):
@@ -771,7 +773,7 @@ class Phone(com_gsm.Phone):
         return result
 
 #-------------------------------------------------------------------------------
-parent_profile=com_gsm.Profile
+parent_profile=com_etsi.Profile
 class Profile(parent_profile):
 
     serialsname=Phone.serialsname
