@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx4400.py 3630 2006-10-25 21:07:20Z djpham $
+### $Id: com_lgvx4400.py 3918 2007-01-19 05:15:12Z djpham $
 
 """Communicate with the LG VX4400 cell phone"""
 
@@ -26,6 +26,7 @@ import p_brew
 import com_brew
 import com_phone
 import com_lg
+import helpids
 import prototypes
 import fileinfo
 import call_history
@@ -36,6 +37,7 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
     "Talk to the LG VX4400 cell phone"
 
     desc="LG-VX4400"
+    helpid=helpids.ID_PHONE_LGVX4400
     wallpaperindexfilename="dloadindex/brewImageIndex.map"
     ringerindexfilename="dloadindex/brewRingerIndex.map"
     protocolclass=p_lgvx4400
@@ -383,9 +385,12 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
                 else:
                     dupecheck[res.entry.serial1]=entry
                 self.progress(i, numentries, res.entry.name)
-            except:
+            except common.PhoneBookBusyException:
+                raise
+            except Exception, e:
                 # Something's wrong with this entry, log it and skip
                 self.log('Failed to read entry %d'%i)
+                self.log('Exception %s raised'%`e`)
                 if __debug__:
                     raise
             #### Advance to next entry
