@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx8100.py 3584 2006-09-29 03:55:29Z djpham $
+### $Id: com_lgvx8100.py 4287 2007-06-12 02:33:21Z djpham $
 
 """Communicate with the LG VX8100 cell phone
 
@@ -37,6 +37,7 @@ import bpcalendar
 import call_history
 import sms
 import memo
+import helpids
 
 
 from prototypes import *
@@ -47,7 +48,7 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
     "Talk to the LG VX8100 cell phone"
 
     desc="LG-VX8100"
-
+    helpid=helpids.ID_PHONE_LGVX8100
     protocolclass=p_lgvx8100
     serialsname='lgvx8100'
 
@@ -433,15 +434,10 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
 
         buf=prototypes.buffer()
         eventsf.writetobuffer(buf, logtitle="New Calendar")
-        # We check the existing calender as changes require a reboot for the alarms
-        # to work properly, also no point writing the file if it is not changing
-        if buf.getvalue()!=self.getfilecontents(self.calendarlocation):
-            self.writefile(self.calendarlocation, buf.getvalue())
-            if contains_alarms or self.calenderrequiresreboot:
-                self.log("Your phone has to be rebooted due to the calendar changing")
-                dict["rebootphone"]=True
-        else:
-            self.log("Phone calendar unchanged, no update required")
+        self.writefile(self.calendarlocation, buf.getvalue())
+        if contains_alarms or self.calenderrequiresreboot:
+            self.log("Your phone has to be rebooted due to the calendar changing")
+            dict["rebootphone"]=True
 
         buf=prototypes.buffer()
         exceptionsf.writetobuffer(buf, logtitle="Writing calendar exceptions")
