@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx8500.py 3809 2006-12-27 05:58:13Z djpham $
+### $Id: com_lgvx8500.py 4216 2007-05-09 01:02:45Z djpham $
 
 """
 Communicate with the LG VX8500 cell phone
@@ -21,16 +21,25 @@ import datetime
 import common
 import com_brew
 import com_lgvx8300
+import helpids
 import fileinfo
+import guihelper
+import os
+import p_brew
 import p_lgvx8500
 import playlist
 import prototypes
 import prototypeslg
 import t9editor
+try:
+    import pyvx8500
+except ImportError:
+    pyvx8500=None
 
 parentphone=com_lgvx8300.Phone
 class Phone(parentphone):
     desc="LG-VX8500"
+    helpid=helpids.ID_PHONE_LGVX8500
 
     protocolclass=p_lgvx8500
     serialsname='lgvx8500'
@@ -246,6 +255,7 @@ class Phone(parentphone):
         _pl_file=self.protocolclass.PLPlayListFile()
         _dt=datetime.datetime.now()
         _onesec=datetime.timedelta(seconds=1)
+        _plsize=0
         for _song in pl.songs:
             if song_info.has_key(_song):
                 _dt-=_onesec
@@ -254,6 +264,10 @@ class Phone(parentphone):
                     date=_dt.timetuple()[:6],
                     size=song_info[_song]['size'])
                 _pl_file.items.append(_entry)
+                _plsize+=1
+                if _plsize>=self.protocolclass.PLMaxSize:
+                    # reached max size
+                    break
         _buf=prototypes.buffer()
         _pl_file.writetobuffer(_buf,
                                logtitle='Writing Playlist '+pl.name)
@@ -316,7 +330,7 @@ class Phone(parentphone):
             pass
         return _current_db
     def _copy_fields(self, old, new):
-        for _field in ('unknown1', 'unknown2', 'unknown3'):
+        for _field in ('unknown1', 'unknown2', 'unknown3', 'unknown4'):
             setattr(new, _field, getattr(old, _field))
     def gett9db(self, result):
         _req=self._get_current_db()
@@ -335,10 +349,13 @@ class Phone(parentphone):
         '9': 0x7FA, '0': 0x800 }
     _t9keys=('1', '2', '3', '4', '5', '6', '7', '8', '9', '0')
     def savet9db(self, result, _):
-        _current_db=self._get_current_db()
         _new_db=self.protocolclass.t9udbfile()
-        if _current_db:
-            self._copy_fields(_current_db, _new_db)
+        try:
+            _current_db=self._get_current_db()
+            if _current_db:
+                self._copy_fields(_current_db, _new_db)
+        except:
+            _current_db=None
         _t9words={}
         _t9list=result.get(t9editor.dict_key, t9editor.T9WordsList())
         _wordcount=0
@@ -363,11 +380,10 @@ class Phone(parentphone):
                 _new_db.blocks.append({ 'type': prototypeslg.T9USERDBBLOCK.FreeBlock_Type,
                                         'value': _free_len })
             else:
-                # ugly hack, again!!
-                if _key=='1':
-                    _type=prototypeslg.T9USERDBBLOCK.FreeBlock_Type
-                else:
-                    _type=prototypeslg.T9USERDBBLOCK.A0FreeBlock_Type
+                if _key!='1':
+                    _new_db.blocks.append({ 'type': prototypeslg.T9USERDBBLOCK.A0_Type,
+                                            'value': 0xA0 })
+                _type=prototypeslg.T9USERDBBLOCK.FreeBlock_Type
                 _new_db.blocks.append({ 'type': _type,
                                         'value': self._buffer_data[_key] })
                 _total_free_size+=self._buffer_data[_key]
@@ -381,6 +397,12 @@ class Phone(parentphone):
         return result
 
     # Misc Stuff----------------------------------------------------------------
+    def get_firmware_version(self):
+        # return the firmware version
+        req=p_brew.firmwarerequest()
+        res=self.sendbrewcommand(req, self.protocolclass.firmwareresponse)
+        return res.firmware
+
     def _unlock_key(self):
         _req=self.protocolclass.LockKeyReq(lock=1)
         self.sendbrewcommand(_req, self.protocolclass.data)
@@ -397,15 +419,94 @@ class Phone(parentphone):
             _req.key=_k
             self.sendbrewcommand(_req, self.protocolclass.data)
 
+    def _enter_DMv4(self):
+        self._lock_key()
+        self._press_key('\x06\x513733929\x51')
+        self._unlock_key()
+        self._in_DM=True
+
+    def _rotate_left(self, value, nbits):
+        return ((value << nbits) | (value >> (32-nbits))) & 0xffffffffL
+    
+    def get_challenge_response(self, challenge):
+        # Reverse engineered and contributed by Nathan Hjelm <hjelmn@users.sourceforge.net>
+        # get_challenge_response(challenge):
+        #    - Takes the SHA-1 hash of a 16-byte block containing the challenge and returns the proper response.
+        #    - The hash used by the vx8700 differs from the standard implementation only in that it does not append a
+        #      1 bit before padding the message with 0's.
+        #
+        #  Return value:
+        #    Last three bytes of the SHA-1 hash or'd with 0x80000000.
+        # IV = (0x67452301, 0xefcdab89, 0x98badcfe, 0x10325476, 0xc3d2e1f0)
+        input_vector = [0x67452301L, 0xefcdab89L, 0x98badcfeL, 0x10325476L, 0xc3d2e1f0L]
+        hash_result  = [0x67452301L, 0xefcdab89L, 0x98badcfeL, 0x10325476L, 0xc3d2e1f0L]
+        hash_data = []
+        hash_data.append(long(challenge))
+        # pad message with zeros as well and zero first word of bit length
+        # if this were standard SHA-1 then 0x00000080 would be appended here as its a 56-bit message
+        for i in range(14):
+            hash_data.append(0L)
+        # append second word of the bit length (56 bit message?)
+        hash_data.append(56L)
+        for i in range(80):
+            j = i & 0x0f
+            if i > 15:
+                index1 = (i -  3) & 0x0f
+                index2 = (i -  8) & 0x0f
+                index3 = (i - 14) & 0x0f
+                hash_data[j] = hash_data[index1] ^ hash_data[index2] ^ hash_data[index3] ^ hash_data[j]
+                hash_data[j] = self._rotate_left (hash_data[j], 1)
+            if i < 20:
+                # f = (B and C) or ((not B) and C), k = 0x5a827999
+                f = (hash_result[1] & hash_result[2]) | ((~hash_result[1]) & hash_result[3])
+                k = 0x5a827999L
+            elif i < 40:
+                # f = B xor C xor D, k = 0x6ed9eba1
+                f = hash_result[1] ^ hash_result[2] ^ hash_result[3]
+                k = 0x6ed9eba1L
+            elif i < 60:
+                # f = (B and C) or (B and D) or (B and C), k = 0x8f1bbcdc
+                f = (hash_result[1] & hash_result[2]) | (hash_result[1] & hash_result[3]) | (hash_result[2] & hash_result[3])
+                k = 0x8f1bbcdcL
+            else:
+                # f = B xor C xor D, k = 0xca62c1d6
+                f = hash_result[1] ^ hash_result[2] ^ hash_result[3]
+                k = 0xca62c1d6L
+            # A = E + rotate_left (A, 5) + w[j] + f + k
+            newA = (hash_result[4] + self._rotate_left(hash_result[0], 5) + hash_data[j] + f + k) & 0xffffffffL
+            # B = oldA, C = rotate_left(B, 30), D = C, E = D
+            hash_result = [newA] + hash_result[0:4]
+            hash_result[2] = self._rotate_left (hash_result[2], 30)
+        for i in range(5):
+            hash_result[i] = (hash_result[i] + input_vector[i]) & 0xffffffffL
+        return 0x80000000L | (hash_result[4] & 0x00ffffffL)
+
+    def _enter_DMv5(self):
+        self._in_DM=True
+        # request the seed
+        _req=self.protocolclass.DMKeyReq()
+        _resp=self.sendbrewcommand(_req, self.protocolclass.DMKeyResp)
+        # respond with the key
+        _key=self.get_challenge_response(_resp.key)
+        if _key is None:
+            self.log('Failed to get the key.')
+            return
+        _req=self.protocolclass.DMReq(key=_key)
+        self.sendbrewcommand(_req, self.protocolclass.DMResp)
+
     def enter_DM(self):
         try:
-            self._lock_key()
-            self._press_key('\x06\x513733929\x51')
-            self._unlock_key()
-            self._in_DM=True
+            _fw_version=self.get_firmware_version()[-1]
+            if self.my_model=='VX8500' and _fw_version>'4':
+                self._enter_DMv5()
+            else:
+                self._enter_DMv4()
+            self.log('Now in DM')
         except:
+            if __debug__:
+                raise
             self.log('Failed to enter DM')
-            self._in_DM=False
+            self._in_DM=True
 
 #-------------------------------------------------------------------------------
 parentprofile=com_lgvx8300.Profile
