@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx9800.py 3788 2006-12-20 23:15:29Z djpham $
+### $Id: com_lgvx9800.py 3937 2007-01-25 03:59:48Z djpham $
 
 """Communicate with the LG VX9800 cell phone
 """
@@ -33,12 +33,13 @@ import call_history
 import sms
 import memo
 import playlist
+import helpids
 
-class Phone(com_lg.LGNewIndexedMedia2,com_lgvx8100.Phone):
+class Phone(com_lgvx8100.Phone):
     "Talk to the LG VX9800 cell phone"
 
     desc="LG-VX9800"
-
+    helpid=helpids.ID_PHONE_LGVX9800
     protocolclass=p_lgvx9800
     serialsname='lgvx9800'
     my_model='VX9800'
