@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_motov3c.py 3460 2006-07-08 23:55:09Z djpham $
+### $Id: com_motov3c.py 4287 2007-06-12 02:33:21Z djpham $
 
 """Communicate with Motorola V3c phones using AT commands"""
 
@@ -14,22 +14,24 @@
 # BitPim modules
 import com_motov710
 import p_motov3c
+import helpids
 
 parentphone=com_motov710.Phone
 class Phone(parentphone):
     desc='Moto-V3c'
+    helpid=helpids.ID_PHONE_MOTOV3C
     serialsname='motov3c'
     protocolclass=p_motov3c
 
     def __init__(self, logtarget, commport):
         parentphone.__init__(self, logtarget, commport)
 
-    def _detectphone(coms, likely_ports, res, _module, _log):
-        pass
-    detectphone=staticmethod(_detectphone)
-
 #------------------------------------------------------------------------------
 parentprofile=com_motov710.Profile
 class Profile(parentprofile):
     serialsname=Phone.serialsname
-    phone_model='Motorola CDMA V3c'
+    # use for auto-detection
+    phone_manufacturer='Motorola'
+    phone_model='V3c '
+    common_model_name='V3c'
+    generic_phone_model='Motorola CDMA V3c Phone'
