@@ -5,29 +5,31 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_motov3cm.py 3460 2006-07-08 23:55:09Z djpham $
+### $Id: com_motov3cm.py 4287 2007-06-12 02:33:21Z djpham $
 
 """Communicate with Motorola V3cm phones using AT commands"""
 
 # BitPim modules
 import com_motov710m
 import p_motov3c
+import helpids
 
 parentphone=com_motov710m.Phone
 class Phone(parentphone):
     desc='Moto-V3cm'
+    helpid=helpids.ID_PHONE_MOTOV3CM
     serialsname='motov3cm'
     protocolclass=p_motov3c
 
     def __init__(self, logtarget, commport):
         parentphone.__init__(self, logtarget, commport)
 
-    def _detectphone(coms, likely_ports, res, _module, _log):
-        pass
-    detectphone=staticmethod(_detectphone)
-
 #------------------------------------------------------------------------------
 parentprofile=com_motov710m.Profile
 class Profile(parentprofile):
     serialsname=Phone.serialsname
-    phone_model='Motorola CDMA V3cM'
+    # use for auto-detection
+    phone_manufacturer='Motorola'
+    phone_model='V3cm'
+    common_model_name='V3c'
+    generic_phone_model='Motorola CDMA V3c Phone'
