@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_motov710.py 3460 2006-07-08 23:55:09Z djpham $
+### $Id: com_motov710.py 3927 2007-01-22 03:15:22Z rogerb $
 
 """Communicate with Motorola phones using AT commands"""
 # system modules
@@ -17,15 +17,17 @@ import bpcalendar
 import common
 import commport
 import com_brew
-import com_moto
+import com_moto_cdma
 import fileinfo
 import nameparser
 import prototypes
 import p_motov710
+import helpids
 
-class Phone(com_moto.Phone):
+class Phone(com_moto_cdma.Phone):
     """ Talk to a Motorola V710 phone"""
     desc='Moto-V710'
+    helpid=helpids.ID_PHONE_MOTOV710
     protocolclass=p_motov710
     serialsname='motov710'
 
@@ -44,7 +46,7 @@ class Phone(com_moto.Phone):
         )
 
     def __init__(self, logtarget, commport):
-        com_moto.Phone.__init__(self, logtarget, commport)
+        com_moto_cdma.Phone.__init__(self, logtarget, commport)
 
     # fundamentals stuff--------------------------------------------------------
     def _get_groups(self):
@@ -640,7 +642,7 @@ class Phone(com_moto.Phone):
     detectphone=staticmethod(_detectphone)
     
 #------------------------------------------------------------------------------
-parentprofile=com_moto.Profile
+parentprofile=com_moto_cdma.Profile
 class Profile(parentprofile):
 
     serialsname=Phone.serialsname
