@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_motov710m.py 3460 2006-07-08 23:55:09Z djpham $
+### $Id: com_motov710m.py 3918 2007-01-19 05:15:12Z djpham $
 
 """Communicate with Motorola phones using AT commands"""
 # system modules
@@ -16,11 +16,13 @@ import bp_obex
 import common
 import com_motov710
 import p_motov710
+import helpids
 
 parentphone=com_motov710.Phone
 class Phone(parentphone):
     """ Talk to a Motorola V710 phone"""
     desc='Moto-V710m'
+    helpid=helpids.ID_PHONE_MOTOV710M
     protocolclass=p_motov710
     serialsname='motov710m'
     MODEOBEX='modeobex'
