@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_samsung.py 2582 2005-10-26 01:28:04Z djpham $
+### $Id: com_samsung.py 3878 2007-01-09 22:28:37Z djpham $
 
 """Communicate with a Samsung SCH-Axx phone using AT commands"""
 # standard modules
@@ -16,7 +16,7 @@ import re
 import time
 
 # site-packages
-from DSV import DSV
+from thirdparty import DSV
 
 # BitPim modules
 import bpcalendar
