@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_samsungscha950.py 3711 2006-12-01 04:29:53Z djpham $
+### $Id: com_samsungscha950.py 4287 2007-06-12 02:33:21Z djpham $
 
 """Communicate with the Samsung SCH-A950 Phone"""
 
@@ -33,9 +33,11 @@ import pubsub
 import p_samsungscha950
 import sqlite2_file
 import sms
+import helpids
 
 class Phone(com_phone.Phone, com_brew.BrewProtocol):
     desc='SCH-A950'
+    helpid=helpids.ID_PHONE_SAMSUNGSCHA950
     protocolclass=p_samsungscha950
     serialsname='scha950'
 
@@ -296,13 +298,16 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         return self._get_media_from_index('ringtone-index', 'ringtone',
                                           fundamentals)
 
-    def _get_del_new_list(self, index_key, media_key, merge, fundamentals):
+    def _get_del_new_list(self, index_key, media_key, merge, fundamentals,
+                          ignored_origins=()):
         """Return a list of media being deleted and being added"""
         _index=fundamentals.get(index_key, {})
         _media=fundamentals.get(media_key, {})
         _index_file_list=[_entry['name'] for _,_entry in _index.items() \
-                          if _entry.has_key('filename')]
-        _bp_file_list=[_entry['name'] for _,_entry in _media.items()]
+                          if _entry.has_key('filename') and \
+                             _entry.get('origin', None) not in ignored_origins]
+        _bp_file_list=[_entry['name'] for _,_entry in _media.items() \
+                       if _entry.get('origin', None) not in ignored_origins]
         if merge:
             # just add the new files, don't delete anything
             _del_list=[]
@@ -1088,10 +1093,9 @@ class CalendarEntry(object):
     _tz_code=None
     def _build_tz(self):
         if CalendarEntry._tz_code is None:
-            CalendarEntry._tz_code=self._build_tz_dict.get(time.timezone, self.TZ_EST)
-            _dt=datetime.datetime.now().timetuple()
-            if time.daylight and \
-               int(time.mktime(_dt)-calendar.timegm(_dt))==time.altzone:
+            CalendarEntry._tz_code=self._build_tz_dict.get(time.timezone,
+                                                           self.TZ_EST)
+            if time.localtime()[-1]==1:
                 # daylight saving time
                 CalendarEntry._tz_code+=1
         return CalendarEntry._tz_code
