@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_samsungspha620.py 3145 2006-04-24 13:17:58Z sawecw $
+### $Id: com_samsungspha620.py 3918 2007-01-19 05:15:12Z djpham $
 
 """Communicate with a Samsung SPH-A620"""
 
@@ -23,6 +23,7 @@ import com_phone
 import com_samsung_packet
 import prototypes
 import fileinfo
+import helpids
 
 numbertypetab=('home','office','cell','pager','fax','none')
 
@@ -30,7 +31,7 @@ class Phone(com_samsung_packet.Phone):
     "Talk to a Samsung SPH-A620 phone"
 
     desc="SPH-A620"
-
+    helpid=helpids.ID_PHONE_SAMSUNGOTHERS
     protocolclass=p_samsungspha620
     serialsname='spha620'
 
