@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_toshibavm4050.py 3037 2006-04-03 00:30:28Z rogerb $
+### $Id: com_toshibavm4050.py 3918 2007-01-19 05:15:12Z djpham $
 
 """Communicate with the toshiba CDM 8900 cell phone"""
 
@@ -22,11 +22,13 @@ import prototypes
 import commport
 import p_brew
 import p_toshibavm4050
+import helpids
 
 class Phone(com_phone.Phone, com_brew.BrewProtocol):
     "Talk to Toshiba VM4050 cell phone"
 
     desc="Toshiba VM4050"
+    helpid=helpids.ID_PHONE_TOSHIBAVM4050
     protocolclass=p_toshibavm4050
     serialsname='toshibavm4050'
     
