@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: sms_tab.py 3647 2006-11-08 03:39:16Z djpham $
+### $Id: sms_tab.py 4206 2007-04-27 20:19:34Z djpham $
 
 """
 Code to handle the SMS Tab of the BitPim main display.
@@ -23,15 +23,19 @@ import wx.gizmos as gizmos
 import wx.lib.scrolledpanel as scrolled
 
 # BitPim modules
+import common
 import database
 import guiwidgets
+import helpids
 import phonebookentryeditor as pb_editor
 import phonenumber
 import pubsub
 import sms
 import today
 import guihelper
+import guiwidgets
 import widgets
+import xyaptu
 
 #-------------------------------------------------------------------------------
 class StaticText(wx.StaticText):
@@ -168,7 +172,7 @@ class SMSWidget(wx.Panel, widgets.BitPimWidget):
         vbs1.Add(self.builtin_canned_list, 1, wx.EXPAND|wx.ALL, 5)
         static_bs1.Add(vbs1, 1, wx.EXPAND|wx.ALL, 5)
         vbs.Add(static_bs1, 1, wx.EXPAND|wx.ALL, 5)
-        self.save_btn=wx.Button(self, wx.NewId(), 'Save')
+        self.save_btn=wx.Button(self, wx.ID_SAVE)
         vbs.Add(self.save_btn, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         self.list_widget=SMSList(self._main_window, self._parent, self)
         wx.EVT_BUTTON(self, self.save_btn.GetId(), self.OnSaveCannedMsg)
@@ -338,6 +342,13 @@ class SMSWidget(wx.Panel, widgets.BitPimWidget):
             self._main_window.OnBusyEnd()
         dlg.Destroy()
 
+    def OnPrintDialog(self, mainwindow, config):
+        dlg=guiwidgets.SMSPrintDialog(self, mainwindow, config)
+        dlg.ShowModal()
+        dlg.Destroy()
+    def CanPrint(self):
+        return True
+
 #-------------------------------------------------------------------------------
 class SMSList(wx.Panel, widgets.BitPimWidget):
     _by_type=0
@@ -571,3 +582,9 @@ class SMSList(wx.Panel, widgets.BitPimWidget):
                 self._item_list.Select(item, 0)
             self.populate()
             self._stats._save_to_db(self._stats._data)
+    def GetHelpID(self):
+        return helpids.ID_TAB_SMS
+    def OnPrintDialog(self, mainwindow, config):
+        self._stats.OnPrintDialog(mainwindow, config)
+    def CanPrint(self):
+        return True
