@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: vcal_calendar.py 3496 2006-07-25 03:18:28Z djpham $
+### $Id: vcal_calendar.py 4179 2007-04-03 01:07:57Z djpham $
 
 "Deals with vcard calendar import stuff"
 
@@ -40,6 +40,37 @@ class vCalendarFile(object):
     def _open(self, name):
         return file(name, 'rt')
 
+    def _read_block(self, vfile):
+        """Read a BEGIN/END block and return a dict of values/params
+        """
+        global module_debug
+        d={}
+        _inblk=False
+        for n,l in vfile:
+            if n[0]=='BEGIN':
+                _blkname=l
+                _inblk=True
+                _vdata=[]
+            elif n[0]=='END' and l==_blkname:
+                d['BEGIN-END']={ 'value': l,
+                                 'params': self._read_block(_vdata) }
+                _inblk=False
+            elif _inblk:
+                _vdata.append((n, l))
+            else:
+                _params={}
+                for _item in n[1:]:
+                    _l=_item.split('=')
+                    if len(_l)==1:
+                        _params[_l[0]]=None
+                    else:
+                        _params[_l[0]]=_l[1]
+                d[n[0]]={ 'value': l,
+                          'params': _params }
+        if module_debug:
+            print d,'\n'
+        return d
+
     def read(self, file_name=None):
         self._data=[]
         if file_name is not None:
@@ -53,23 +84,13 @@ class vCalendarFile(object):
             has_data=False
             for n,l in vfile:
                 if n[0]=='BEGIN' and l=='VEVENT':
-                    # start of an event, turn on data loggin
-                    d={}
                     has_data=True
+                    _vdata=[]
                 elif n[0]=='END' and l=='VEVENT':
-                    self._data.append(d)
-                    d={}
                     has_data=False
+                    self._data.append(self._read_block(_vdata))
                 elif has_data:
-                    _params={}
-                    for _item in n[1:]:
-                        _l=_item.split('=')
-                        if len(_l)==1:
-                            _params[_l[0]]=None
-                        else:
-                            _params[_l[0]]=_l[1]
-                    d[n[0]]={ 'value': l,
-                              'params': _params }
+                    _vdata.append((n, l))
             f.close()
         except:
             if __debug__:
@@ -160,7 +181,10 @@ class VCalendarImportData(object):
             rp.repeat_type=rp_type
             rp.interval=rp_interval
             rp.interval2=rp_interval2
-            rp.dow=rp_dow
+            if rp_dow:
+                rp.dow=rp_dow
+            else:
+                rp.dow=ce.start
         elif rp_type==rp.yearly:
             rp.repeat_type=rp.yearly
         else:
@@ -248,6 +272,7 @@ class VCalendarImportData(object):
         return l
         
     def get(self):
+        global module_debug
         res={}
         single_rpt=self._filter.get('rpt_events', False)
         for k in self._data:
@@ -338,6 +363,7 @@ class VCalendarImportData(object):
         return True
 
     def _process_monthly_rule(self, v, dd):
+        global module_debug
         try:
             # acceptable format: MD1 <day number> <end date | #duration>
             # or MP1 <[1-4]+ | 1-> <SU-SA> <end date | #duration>
@@ -370,6 +396,7 @@ class VCalendarImportData(object):
             if module_debug: raise
             return False
     def _process_yearly_rule(self, v, dd):
+        global module_debug
         try:
             # acceptable format YM1 <Month number> <end date | #duration>
             s=v['value'].split(' ')
@@ -421,6 +448,7 @@ class VCalendarImportData(object):
         ('EXDATE', 'exceptions', _conv_exceptions),
         ]
     def _convert(self, vcal, d):
+        global module_debug
         for i in vcal:
             try:
                 dd={'start': None, 'end': None }
@@ -485,7 +513,6 @@ class VcalImportCalDialog(common_calendar.PreviewDialog):
         ('alarm', 'Alarm', 80, common_calendar.bp_alarm_str),
         ('categories', 'Category', 150, common_calendar.category_str)
         ]
-    ID_ADD=wx.NewId()
     _filetype_label="VCalendar File:"
     _data_type='vCalendar'
     _import_data_class=VCalendarImportData
@@ -518,6 +545,7 @@ class VcalImportCalDialog(common_calendar.PreviewDialog):
         hbs.Add(wx.Button(self, id_import, 'Import'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs.Add(wx.Button(self, wx.ID_OK, 'Replace All'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs.Add(wx.Button(self, self.ID_ADD, 'Add'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
+        hbs.Add(wx.Button(self, self.ID_MERGE, 'Merge'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         hbs.Add(wx.Button(self, wx.ID_CANCEL, 'Cancel'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         id_filter=wx.NewId()
         hbs.Add(wx.Button(self, id_filter, 'Filter'), 0, wx.ALIGN_CENTRE|wx.ALL, 5)       
@@ -525,7 +553,8 @@ class VcalImportCalDialog(common_calendar.PreviewDialog):
         main_bs.Add(hbs, 0, wx.ALIGN_CENTRE|wx.ALL, 5)
         wx.EVT_BUTTON(self, id_import, self.OnImport)
         wx.EVT_BUTTON(self, id_filter, self.OnFilter)
-        wx.EVT_BUTTON(self, self.ID_ADD, self.OnAdd)
+        wx.EVT_BUTTON(self, self.ID_ADD, self.OnEndModal)
+        wx.EVT_BUTTON(self, self.ID_MERGE, self.OnEndModal)
         wx.EVT_BUTTON(self, wx.ID_HELP, lambda *_: wx.GetApp().displayhelpid(helpids.ID_DLG_CALENDAR_IMPORT))
 
     def OnImport(self, evt):
@@ -562,8 +591,8 @@ class VcalImportCalDialog(common_calendar.PreviewDialog):
             self._oc.set_filter(dlg.get())
             self.populate(self._oc.get_display_data())
 
-    def OnAdd(self, evt):
-        self.EndModal(self.ID_ADD)
+    def OnEndModal(self, evt):
+        self.EndModal(evt.GetId())
 
     def get(self):
         return self._oc.get()
