@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: wallpaper.py 3585 2006-09-29 03:56:55Z djpham $
+### $Id: wallpaper.py 4226 2007-05-09 21:21:04Z djpham $
 
 "Deals with wallpaper and related views"
 
@@ -261,31 +261,6 @@ class WallpaperView(fileview.FileView):
     def GetFileInfo(self, filename):
         return fileinfo.identify_imagefile(filename)
 
-    def OnPaste(self, evt=None):
-        super(WallpaperView, self).OnPaste(evt)
-        if not wx.TheClipboard.Open():
-            # can't access the clipboard
-            return
-        if wx.TheClipboard.IsSupported(wx.DataFormat(wx.DF_BITMAP)):
-            do=wx.BitmapDataObject()
-            success=wx.TheClipboard.GetData(do)
-        else:
-            success=False
-        wx.TheClipboard.Close()
-        if success:
-            # work out a name for it
-            self.OnAddImage(wx.ImageFromBitmap(do.GetBitmap()), None)
-
-    def CanPaste(self):
-        """ Return True if can accept clipboard data, False otherwise
-        """
-        if not wx.TheClipboard.Open():
-            return False
-        r=wx.TheClipboard.IsSupported(wx.DataFormat(wx.DF_FILENAME)) or\
-           wx.TheClipboard.IsSupported(wx.DataFormat(wx.DF_BITMAP))
-        wx.TheClipboard.Close()
-        return r
-
     def OnAddFiles(self, filenames):
         for file in filenames:
             file_stat=os.stat(file)
@@ -659,7 +634,10 @@ def BPFSImageFile(fshandler, location, name=None, img=None, width=-1, height=-1,
     various wxPython bugs it instead returns the parameters to make a
     wx.FSFile since a new one has to be made every time.
     """
-        # special fast path if we aren't resizing or converting image
+    # if this is a bad or non-existing image file, use the dummy one!
+    if name is None and img is None:
+        name=guihelper.getresourcefile('wallpaper.png')
+    # special fast path if we aren't resizing or converting image
     if img is None and width<0 and height<0:
         mime=guihelper.getwxmimetype(name)
         # wxPython 2.5.3 has a new bug and fails to read bmp files returned as a stream
@@ -931,22 +909,6 @@ class ImageCropSelect(wx.ScrolledWindow):
     def GetPreview(self):
         w,h=self.resultsize
         l,t,r,b=self.anchors
-        scale=max(float(w+0.99999)/(r-l), float(h+0.99999)/(b-t))
-
-        # we are fine using this to scale down
-        if True and scale<1:
-            sub=wx.EmptyBitmap(w,h)
-            mdcsub=wx.MemoryDC()
-            mdcsub.SelectObject(sub)
-            mdcsub.SetUserScale(scale, scale)
-            mdc=wx.MemoryDC()
-            mdc.SelectObject(self.thebmp)
-            mdcsub.Blit(0,0,r-l,b-t,mdc,l,t)
-
-            mdc.SelectObject(wx.NullBitmap)
-            mdcsub.SelectObject(wx.NullBitmap)
-            return sub
-
         sub=self.thebmp.GetSubBitmap( (l,t,(r-l),(b-t)) )
         sub=sub.ConvertToImage()
         sub.Rescale(w,h)
@@ -1012,7 +974,7 @@ class ImagePreviewDialog(wx.Dialog):
         self.vbs.Add(self.colourselect, 0, wx.ALL|wx.EXPAND, 5)
         wx.lib.colourselect.EVT_COLOURSELECT(self, self.colourselect.GetId(), self.OnBackgroundColour)
         self.vbs.Add(wx.StaticText(self, -1, "Target"), 0, wx.ALL, 5)
-        self.targetbox=wx.ListBox(self, size=(-1,100))
+        self.targetbox=wx.ListBox(self, -1, size=(-1,100))
         self.vbs.Add(self.targetbox, 0, wx.EXPAND|wx.ALL, 5)
         self.vbs.Add(wx.StaticText(self, -1, "Scale"), 0, wx.ALL, 5)
 
@@ -1075,12 +1037,11 @@ class ImagePreviewDialog(wx.Dialog):
 
     def OnTargetSelect(self, _):
         self.target=self.targetbox.GetStringSelection()
-        w,h=self.targets[self.target]['width'],self.targets[self.target]['height']
-        self.SetupControls(self.vbsouter)
-        self.imagepreview.SetSize( (w,h) )
-        self.cropselect.setresultsize( (w, h) )
-        self.vbsouter.Layout()
-        self.Refresh(True)
+        if self.targets.has_key(self.target):
+            w,h=self.targets[self.target]['width'],self.targets[self.target]['height']
+            self.imagepreview.SetSize( (w,h) )
+            self.cropselect.setresultsize( (w, h) )
+            self.Refresh(True)
         
     def GetResultImage(self):
         if self.skip:
